<?php

//mb_internal_encoding("utf-8");
/**
 * FactoryOrder.php
 *
 * PHP Version 5.3.0
 * 
 * @category  category
 * @package   package
 * @author    Alexander Arcila <alexander.arcila@ingeneo.com.co>
 * @copyright 2013 INGENEO S.A.S.
 * @license   http://www.opensource.org/licenses/bsd-license.php  BSD License
 * @version   SVN: $Id$
 * @link      http://www.ingeneo.com.co
 * 
 */

/**
 * FactoryOrder.php
 *
 * Clase para crear el xml del pedido
 *
 * @category  category
 * @package   package
 * @author    Alexander Arcila <alexander.arcila@ingeneo.com.co>
 * @copyright 2013 INGENEO S.A.S.
 * @license   http://www.opensource.org/licenses/bsd-license.php  BSD License
 * @version   Release: $Id$
 * @link      http://www.ingeneo.com.co
 * 
 */
class FactoryOrder {

    /**
     * @const Constante para definir las variables de tipo int
     */
    const TYPE_INT = 'int';

    /**
     * @const Constante para definir las variables de tipo string
     */
    const TYPE_STRING = 'string';

    /**
     * Constructor de la clase
     * 
     * @return void
     * @author    Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @version   SVN: $Id$
     * @copyright 2013 INGENEO S.A.S.     
     * @access public     
     */
    public function __construct() {
        
    }

    /**
     * Funcion desctructora 
     * 
     * @return void
     * @author    Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @version   SVN: $Id$
     * @copyright 2013 INGENEO S.A.S. 
     * @access    public     
     */
    public function __destruct() {
        
    }

    /**
     * Metodo para crear la linea del servicio
     * 
     * @param ItemOrder $item Objeto de entrada
     * 
     * @return    string|boolean
     * @author    Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2013 INGENEO S.A.S.
     * @license   http://www.opensource.org/licenses/bsd-license.php  BSD License
     * @version   Release: $Id$
     * @link      http://www.ingeneo.com.co
     */
    private function _createLine($objectItem) {
        $itemOrder = new ItemOrder();
        $varsInt = $itemOrder->lehgthVarsInt();
        $varsString = $itemOrder->lehgthVarsString();
        $string = $this->_objectString($objectItem, $varsInt, $varsString);
        if (!empty($string) && $string) {
            $line = '<Linea>' . $string . '</Linea>';
            return $line;
        }
        return false;
    }

    /**
     * Metodo para crear la cabecera del pedido
     * 
     * @param object $objectHeader Objeto cabecera
     * 
     * @return    string|boolean
     * @author    Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2013 INGENEO S.A.S.
     * @license   http://www.opensource.org/licenses/bsd-license.php BSD License
     * @version   Release: $Id$
     * @link      http://www.ingeneo.com.co
     */
    private function _createHeader($objectHeader) {
        $headerOrder = new HeaderOrder();
        $varsInt = $headerOrder->lehgthVarsInt();
        $varsString = $headerOrder->lehgthVarsString();
        $string = $this->_objectString($objectHeader, $varsInt, $varsString);
        if (!empty($string) && $string) {
            $line = '<Linea>' . $string . '</Linea>';
            return $line;
        }
        return false;
    }

    /**
     * Metodo para crear el pie de las lineas
     * 
     * @param int $countItem cantidad de items
     * 
     * @return string/boolean
     * @author    Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2013 INGENEO S.A.S.
     * @license   http://www.opensource.org/licenses/bsd-license.php BSD License
     * @version   Release: $Id$
     * @link      http://www.ingeneo.com.co
     */
    private function _createFoot($countItem) {
        if (!empty($countItem) && is_int($countItem)) {
            $typeVar = self::TYPE_INT;
            $lenght = 7;
            $string = $this->_completeVar($countItem, $lenght, $typeVar);
            $complement = '<Linea>' . $string . '99990001001</Linea>';
            return $complement;
        }
        return false;
    }

    /**
     * Funcion para completar las variables 
     * 
     * @param string $value   Valor
     * @param int    $lenght  Tamaño
     * @param string $typeVar Tipo de variable
     * 
     * @return type
     * @author    Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2013 INGENEO S.A.S.
     * @license   http://www.opensource.org/licenses/bsd-license.php  BSD License
     * @version   Release: $Id$
     * @link      http://www.ingeneo.com.co
     */
    private function _completeVar($value, $lenght, $typeVar) {
        $result = '';
        if (!empty($lenght) && is_int($lenght) && !empty($typeVar)) {
            if ($typeVar === self::TYPE_STRING) {
                //$value = utf8_decode($value);
                //$result = str_pad($value, $lenght, " ", STR_PAD_RIGHT);              
                $diff = strlen($value) - mb_strlen($value, mb_detect_encoding($value));
                $result = str_pad($value, $lenght + $diff, " ", STR_PAD_RIGHT);
            } elseif ($typeVar === self::TYPE_INT) {
                $result = str_pad($value, $lenght, "0", STR_PAD_LEFT);
            }
        }
        return $result;
    }

    /**
     * Metodo para convertir el objeto 
     * en una cadena y completar con 0 o espacio segun 
     * el tipo de dato
     * 
     * @param object $objectItem Objeto
     * @param array  $varsInt    Array variables de tipo int
     * @param array  $varsString Array variables de tipo string
     * 
     * @return string
     * @author    Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2013 INGENEO S.A.S.
     * @license   http://www.opensource.org/licenses/bsd-license.php  BSD License
     * @version   Release: $Id$
     * @link      http://www.ingeneo.com.co
     */
    private function _objectString($objectItem, $varsInt, $varsString) {
        $data = '';
        if (is_object($objectItem)) {
            foreach ($objectItem as $var => $value) {
                if (isset($varsInt[$var])) {
                    $typeVar = self::TYPE_INT;
                    $lenght = $varsInt[$var];
                } elseif (isset($varsString[$var])) {
                    $typeVar = self::TYPE_STRING;
                    $lenght = $varsString[$var];
                } else {
                    Yii::log('El atributo {' . $var . '} no esta definido', CLogger::LEVEL_ERROR, 'b2b.xml');
                    return false;
                }

                if ($var === 'cantPedidaBase') {
                    $value .= '.0000';
                }
                if ($var === 'precioUnitario') {
                    $value .= '.0000';
                }

                $data .= $this->_completeVar($value, $lenght, $typeVar);
            }
        }
        return $data;
    }

    /**
     * Metodo que retorna el XML
     * basico para enviar los pedidos
     * 
     * @return string
     * @author    Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2013 INGENEO S.A.S.
     * @license   http://www.opensource.org/licenses/bsd-license.php BSD License
     * @version   Release: $Id$
     * @link      http://www.ingeneo.com.co
     */
    private function _getBasicXML() {
        return '
            <Importar>  
                <NombreConexion>'
                . Yii::app()->params['paramsWs']['nameConection']
                . '</NombreConexion>  
                <IdCia>'
                . Yii::app()->params['paramsWs']['idCompania']
                . '</IdCia> 
                <Usuario>'
                . Yii::app()->params['paramsWs']['usuario']
                . '</Usuario> 
                <Clave>'
                . Yii::app()->params['paramsWs']['clave']
                . '</Clave> 
                <Datos>
                <Linea>000000100000001001</Linea>
                %__CABECERA__%
                %__LINEA__%
                %__FOOT__%                
                </Datos>
                </Importar>
            ';
    }

    /**
     * Metodo para crear el xml que sera 
     * enviado al servicio con la informacion del 
     * pedido
     * 
     * @param object $summaryItems Objeto con el array de items
     * 
     * @return    boolean/string
     * @author    Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2013 INGENEO S.A.S.
     * @license   http://www.opensource.org/licenses/bsd-license.php BSD License
     * @version   Release: $Id$
     * @link      http://www.ingeneo.com.co
     */
    private function _createXML($objectHeader, $summaryItems) {
        if (is_object($summaryItems) && isset($summaryItems->arrayItems) && count($summaryItems->arrayItems) > 0) {
            $arrayItems = $summaryItems->arrayItems;
            $summaryLine = '';
            $resultHeader = $this->_createHeader($objectHeader);

            if (empty($resultHeader) || !$resultHeader) {
                return false;
            }
            if (count($arrayItems) > 0) {
                $countLine = 3;
                foreach ($arrayItems as $key => $tempItem) {
                    $item = $tempItem;
                    $item->nroRegistro = count($arrayItems);
                    $item->numeroReg = $countLine;
                    $resultLine = $this->_createLine($item);
                    if (!empty($resultLine) && $resultLine) {
                        $countLine++;
                        $summaryLine .= $resultLine;
                    } else {
                        return false;
                    }
                }
            }

            $resultFoot = $this->_createFoot($countLine);
            $basicXml = $this->_getBasicXML();
            $arrayString = array('%__CABECERA__%', '%__LINEA__%', '%__FOOT__%');
            $arrayResult = array($resultHeader, $summaryLine, $resultFoot);
            $xml = str_replace($arrayString, $arrayResult, $basicXml);
            return $xml;
        }
        return false;
    }

    /**
     * Metodo para la creacion del xml 
     * de conexion 
     * 
     * @return string
     * @author    Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2013 INGENEO S.A.S.
     * @license   http://www.opensource.org/licenses/bsd-license.php BSD License
     * @version   Release: $Id$
     * @link      http://www.ingeneo.com.co
     */
    public function createXmlConnection() {
        return '
            <?xml version="1.0"?>	
            <Conexion>  
                <NombreConexion>'
                . Yii::app()->params['paramsWs']['nameConection']
                . '</NombreConexion> 
                <TipoBD>SQL</TipoBD> 
                <NombreBD>'
                . Yii::app()->params['paramsWs']['nombreDB']
                . '</NombreBD>
                <NombreServidorBD>'
                . Yii::app()->params['paramsWs']['nombreServidorDB']
                . '</NombreServidorBD>
                <UsuarioBD>'
                . Yii::app()->params['paramsWs']['usuarioDB']
                . '</UsuarioBD> 
                <ClaveBD>'
                . Yii::app()->params['paramsWs']['claveDB']
                . '</ClaveBD> 
                <NumConexionImpo>1</NumConexionImpo>
            </Conexion>
            ';
    }

    /**
     * Metodo que crea el XML del pedido a partir del modelo
     * Se $model no se envia o se envia NULL, la funcion 
     * calcula desde base de datos si esta existe, la carga 
     * y genera el xml
     * 
     * @param int   $idOrder Identificador de la orden
     * @param Order $model   Modelo tipo Order
     * 
     * @return boolean
     * @author    Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2013 INGENEO S.A.S.
     * @license   http://www.opensource.org/licenses/bsd-license.php BSD License
     * @version   Release: $Id$
     * @link      http://www.ingeneo.com.co
     */
    public function createOrder($idOrder, $model = null, $assignPrice = false) {
        $arrayXml = array();
        try {
            if (!empty($idOrder) && is_numeric($idOrder)) {
                if (is_null($model)) {
                    $model = Order::model()->findByAttributes(
                            array("ord_id" => $idOrder));
                }
                if (!empty($model)) {
                    $helperOrder = new HelperOrder();
                    $objectHeader = $helperOrder->createHeader($model);
                    
                    $arrayOrderProduct = OrderProduct::model()->findAllByAttributes(
                            array("orp_ord_id" => $model->ord_id));
                    $summaryItems = new SummaryItems();
                    $summaryItemsFrios = new SummaryItems();
                    if (count($arrayOrderProduct) > 0) {
                        $countItems = count($arrayOrderProduct);
                        //Consultamos todas las sublineas de las referencias pedidas
                        foreach ($arrayOrderProduct as $orderProduct) {
                            $referencias[] = "'" . $orderProduct->orp_reference . "'";
                        }
                        //consultasmo las sublines -----------------------------
                        $sublines = ClientSiesa::getSublineaReferencias(implode(',', $referencias));                        
                        //Buscamos las bodegas de frios por centro de operacion 
                        $idCo = $helperOrder->getIdCo();
                        $frios = false;
                        $bodegasCOFrios = Yii::app()->params['bodegasCOFrios'];
                        if(isset($bodegasCOFrios[$idCo])){
                            $coBodegas = $bodegasCOFrios[$idCo];
                            $frios = true;
                        }  
                        $ciudad = ClientSiesa::getCiudad($model->ord_nit, 
                                $model->ord_codeBranch);
                        //------------------------------------------------------
                        $tmpBodegaCiudad = Citycellar::model()->findByAttributes(
                            array(
                                "cce_country_id" => $ciudad['id_pais'],
                                "cce_depto_id" => $ciudad['id_depto'],
                                "cce_city_id" => $ciudad['id_ciudad'],
                                ));
                                
                        $bodegaCiudad = '';
                        if(isset($tmpBodegaCiudad->cce_cellar) 
                                && !empty($tmpBodegaCiudad->cce_cellar)){
                            $bodegaCiudad = $tmpBodegaCiudad->cce_cellar;
                        }
                        //Creamos cada item ------------------------------------
                        foreach ($arrayOrderProduct as $orderProduct) {                                                        
                            //Consultamos la bodega de cada item ---------------
                            if(empty($bodegaCiudad)){
                                $idBodega = BodegaCo::getIdBodega(
                                    $idCo, 
                                    $orderProduct->orp_reference, 
                                    $sublines);
                            }else{
                                $idBodega = $bodegaCiudad;
                            }
                            
                            //Verificamos el inventarios de cada item ----------           
                            $inventario = ClientSiesa::getInventarioRef(
                                    $orderProduct->orp_reference, $idBodega);
                            //Guardamos el inventario de cada item -------------
                            $orderProduct->orp_und_exist = $inventario;
                            $orderProduct->save(); 
                            //--------------------------------------------------                                                      
                            if($frios && in_array($idBodega, $coBodegas)){
                                $summaryItemsFrios->arrayItems[] = $helperOrder->createItem(
                                    $orderProduct, $countItems, $assignPrice, $idBodega, $model);
                            }else{
                                $summaryItems->arrayItems[] = $helperOrder->createItem(
                                    $orderProduct, $countItems, $assignPrice, $idBodega, $model);
                            }                             
                        }
                        
                        //Validamos el envio de nitificacion al vendedor -------
                        //en caso de tener inventario en 0 ---------------------
                        
                        Order::sendMailVendedor($model);   
                        //------------------------------------------------------ 
                    }                    
                    //Creamos XML para FRIOS -----------------------------------
					if(is_array($summaryItemsFrios->arrayItems) && count($summaryItemsFrios->arrayItems)>0){
						$objectHeaderFrios = $helperOrder->createHeader($model, true);
						$xmlFrios = $this->_createXML($objectHeaderFrios, $summaryItemsFrios);
						$arrayXml[] = str_replace("&amp;", "&", $xmlFrios);
					}
                    //Creamos XML para los demas -------------------------------
					if(is_array($summaryItems->arrayItems) && count($summaryItems->arrayItems)>0){
						$xml = $this->_createXML($objectHeader, $summaryItems);
						$arrayXml[] = str_replace("&amp;", "&", $xml);
					}					
                }
            }
        } catch (Exception $exc) {
            //----------------------------------------------------
            Yii::log(__FILE__ . ':' . __LINE__ . ':' . __FUNCTION__ . ':'
                    . ' {' . $exc->getMessage() . '}', CLogger::LEVEL_ERROR, 'b2b.ws');
            //---------------------------------------------------            
        }
        return $arrayXml;
    }

}

?>
