<?php

class BudgetController extends Controller
{
	/**
	 * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
	 * using two-column layout. See 'protected/views/layouts/column2.php'.
	 */
	public $layout='//layouts/column2';

	/**
	 * @return array action filters
	 */
	public function filters()
	{
		return array(
			'accessControl', // perform access control for CRUD operations
			'postOnly + delete', // we only allow deletion via POST request
		);
	}

	/**
	 * Specifies the access control rules.
	 * This method is used by the 'accessControl' filter.
	 * @return array access control rules
	 */
	public function accessRules() {
        return array(
            array('allow', // allow authenticated users to access all actions
                'users' => array('@'),
            ),
            array('deny'),
        );
    }

	/**
	 * Displays a particular model.
	 * @param integer $id the ID of the model to be displayed
	 */
	public function actionView($id)
	{
		$this->render('view',array(
			'model'=>$this->loadModel($id),
		));
	}

	/**
	 * Creates a new model.
	 * If creation is successful, the browser will be redirected to the 'view' page.
	 */
	public function actionCreate()
	{
		$model= new Budget;
                $client = new Client;
                $idUser = User::getId();
                $defaultBranch = "";
                $defaultClient = "";                
                //obtenemos listado de clientes
                $listClient = $client->getListClientSaveBudget($idUser);
                if (count($listClient) > 0) {
                    $defaultClient = key($listClient);
                }
                                                
                //obtenemos listado de sucursales inicial
                $listBranch = $client->getListBranchBudget($defaultClient);
                if (count($listBranch) > 0) {
                    if (empty($defaultBranch))
                        $defaultBranch = key($listBranch);
                } 
                
		// Uncomment the following line if AJAX validation is needed
		// $this->performAjaxValidation($model);
                
                if (isset($_POST['Budget'])) {                     
                    $model->attributes = Yii::app()->purifier->purify($_POST['Budget']);                       
                    $defaultBranch = $model->id_cln_id;
                    $defaultClient = $_POST['codClient'];
                    $nit = Yii::app()->purifier->purify($_POST['codClient']);
                    $client = new Client;
                    $listBranch = $client->getListBranchBudget($nit);                    
                    if($model->save()){
		       $this->redirect(array('view','id'=>$model->bud_id));
                    }
                }
                
		$this->render('create',array(
			'model'=>$model,
                        'listBranch' => $listBranch,
                        'listClient' => $listClient,
                        'defaultBranch' => $defaultBranch,
                        'defaultClient' => $defaultClient,
		));
	}
        
        
        /**
     * Metodo para obetener el listado de 
     * las sucursales segun el cliente
     */
    public function actionGetListBranchBudget() {
        
        if (isset($_POST['nit'])) {
            $this->layout = '//layouts/column3';
            $defaultBranch = '';
            $nit = Yii::app()->purifier->purify($_POST['nit']);
            $client = new Client;
            $model= new Budget;
            $listBranch = $client->getListBranchBudget($nit);
            $this->render('_selectBranch', array(
                'listBranch' => $listBranch,
                'model' => $model,
                ));
            }
    }
    
    public function actionGetListBranchBudgetSearch() {
        
        if (isset($_POST['nit'])) {
            $this->layout = '//layouts/column3';
            $defaultBranch = '';
            $nit = Yii::app()->purifier->purify($_POST['nit']);
            $client = new Client;
            $model= new Budget;
            $listBranch = $client->getListBranchBudgetSearch($nit);
            $this->render('_selectBranch', array(
                'listBranch' => $listBranch,
                'model' => $model,
                ));
            }
    }

    /**
	 * Updates a particular model.
	 * If update is successful, the browser will be redirected to the 'view' page.
	 * @param integer $id the ID of the model to be updated
	 */
	public function actionUpdate($id)
	{
		$model=$this->loadModel($id);
                
                $client = new Client;
                $idUser = User::getId();
                $defaultBranch = $model->id_cln_id;
                $defaultClient = $model->id_cln_id;
                $list = $client->getListClientUpdateBudget($idUser);
                $listClient = $list[0];
                $listBranch = $list[1];
                
                if (isset($_POST['Budget']) && !empty($_POST['Budget'])) {                                        
                    $model->attributes = Yii::app()->purifier->purify($_POST['Budget']);                      
                    if($model->save()){
		       $this->redirect(array('view','id'=>$model->bud_id));
                    }
                    
                }

		$this->render('update',array(
			'model'=>$model,
                        'listBranch' => $listBranch,
                        'listClient' => $listClient,
                        'defaultBranch' => $defaultBranch,
                        'defaultClient' => $defaultClient,
		));
	}

	/**
	 * Deletes a particular model.
	 * If deletion is successful, the browser will be redirected to the 'admin' page.
	 * @param integer $id the ID of the model to be deleted
	 */
	public function actionDelete($id)
	{
		$this->loadModel($id)->delete();

		// if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
		if(!isset($_GET['ajax']))
			$this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
	}

	/**
	 * Lists all models.
	 */
	public function actionIndex()
	{       
                $criteria = new CDbCriteria();
                $criteria->join ='LEFT JOIN b2b_client c on t.id_cln_id = c.cln_id';
                $criteria->addSearchCondition('cln_usr_user_ID',User::getId());
		$dataProvider=new CActiveDataProvider('Budget',array('criteria'=>$criteria));
                
		$this->render('index',array(
			'dataProvider'=>$dataProvider,
		));
	}

	/**
	 * Manages all models.
	 */
	public function actionAdmin()
	{       
                $client = new Client;
                $idUser = User::getId();
                $client = new Client;
                $idUser = User::getId();
                $defaultBranch = "";
                $defaultClient = "";
                
                //obtenemos listado de clientes
                $listClient = $client->getListClientSaveBudget($idUser);
                if (count($listClient) > 0) {
                    $defaultClient = key($listClient);
                }
                                                
                //obtenemos listado de sucursales inicial
                $listBranch = $client->getListBranchBudget($defaultClient);
                if (count($listBranch) > 0) {
                    if (empty($defaultBranch))
                        $defaultBranch = key($listBranch);
                }                
                
		$model=new Budget('search');
		$model->unsetAttributes();  // clear any default values                
                
		if(isset($_GET['Budget']))
			$model->attributes=$_GET['Budget'];

		$this->render('admin',array(
			'model'=>$model,
                        'listBranch' => $listBranch,
                        'listClient' => $listClient,
                        'defaultBranch' => $defaultBranch,
                        'defaultClient' => $defaultClient,
		));
	}

	/**
	 * Returns the data model based on the primary key given in the GET variable.
	 * If the data model is not found, an HTTP exception will be raised.
	 * @param integer $id the ID of the model to be loaded
	 * @return Budget the loaded model
	 * @throws CHttpException
	 */
	public function loadModel($id)
	{
		$model=Budget::model()->findByPk($id);
		if($model===null)
			throw new CHttpException(404,'The requested page does not exist.');
		return $model;
	}

	/**
	 * Performs the AJAX validation.
	 * @param Budget $model the model to be validated
	 */
	protected function performAjaxValidation($model)
	{
		if(isset($_POST['ajax']) && $_POST['ajax']==='budget-form')
		{
			echo CActiveForm::validate($model);
			Yii::app()->end();
		}
	}
}
