<?php

class OrderController extends Controller {

    /**
     * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
     * using two-column layout. See 'protected/views/layouts/column2.php'.
     */
    public $layout = '//layouts/column2';

    /**
     * @return array action filters
     */
    public function filters() {
        return array(
            'accessControl', // perform access control for CRUD operations
            'postOnly + delete', // we only allow deletion via POST request
        );
    }

    /**
     * Specifies the access control rules.
     * This method is used by the 'accessControl' filter.
     * @return array access control rules
     */
    public function accessRules() {
        return array(
            array('allow', // allow authenticated users to access all actions
                'users' => array('@'),
            ),
            array('deny'),
        );
    }

    /**
     * Displays a particular model.
     * @param integer $id the ID of the model to be displayed
     */
    public function actionView($id) {
//Valida si se tiene acceso a la liquidacion del pedido-----------------

        $client = new Client;
        $model = $this->loadModel($id);
        if (!$model->validateLiquidateOrder($id)) {
            $url = Yii::app()->createUrl("/order/admin");
            $this->redirect($url);
        }
        $nameClient = $client->getNameClient($model->ord_nit);
        $nameBranch = $client->getNameBranch($model->ord_nit, $model->ord_codeBranch);

        $orderProduct = new OrderProduct;
        $listProduct = $orderProduct->getProducts($model->ord_id);

        $this->render('view', array(
            'model' => $model,
            'nameBranch' => $nameBranch,
            'nameClient' => $nameClient,
            'listProduct' => $listProduct,
        ));
    }

    /**
     * Creates a new model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     */
    public function actionCreate() {
        $model = new Order;
        // Uncomment the following line if AJAX validation is needed
        // $this->performAjaxValidation($model);
        if (isset($_POST['Order'])) {
            $model->attributes = $_POST['Order'];
            if ($model->save()) {
                $this->redirect(array('view', 'id' => $model->ord_id));
            }
        }

        $this->render('create', array(
            'model' => $model,
        ));
    }

    /**
     * Creates a new model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * 
     * @author Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2013 INGENEO S.A.S.
     * @license http://www.opensource.org/licenses/bsd-license.php  BSD License
     * @version Release: $Id$
     */
    public function actionCreateorder() {
        $model = new Order;
        $client = new Client;
        $defaultBranch = '';
        $defaultClient = '';
        $listBranch = array();
        $totalIva = 0;
        $summary = false;
        $this->layout = '//layouts/column1';
        // Uncomment the following line if AJAX validation is needed
        //Validacion de campos -------------------------------------------------
        $this->_postAjax($model);
        //----------------------------------------------------------------------
        $idUser = User::getId();
        $listClient = $client->getListClientSave($idUser);
        if (count($listClient) > 0) {
            $defaultClient = key($listClient);
        }
        //----------------------------------------------------------------------
        $listBranch = $client->getListBranch($defaultClient);
        if (count($listBranch) > 0) {
            if (empty($defaultBranch))
                $defaultBranch = key($listBranch);
        }        
        //----------------------------------------------------------------------
        $this->_postSave($model);
        //----------------------------------------------------------------------
        $this->render('createOrder', array(
            'model' => $model,
            'listBranch' => $listBranch,
            'listClient' => $listClient,
            'defaultBranch' => $defaultBranch,
            'defaultClient' => $defaultClient,
            'totalIva' => $totalIva,
            'summary' => $summary,
        ));
    }
    
    /**
     * Metodo para AJAX para validar los pedidos
     * 
     * @author Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2013 INGENEO S.A.S.
     * @license http://www.opensource.org/licenses/bsd-license.php  BSD License
     * @version Release: $Id$
     */
    private function _postAjax(&$model){
        if (isset($_POST['ajax']) && $_POST['ajax'] === 'order-form') {
            $model->attributes = Yii::app()->purifier->purify($_POST['Order']);
            $model->scenario = 'createOrder';
            $model->validate();
            $error = true;
            //------------------------------------------------------------------
            if (isset($_POST['orp_amount'])) {
                $quantitys = Yii::app()->purifier->purify($_POST['orp_amount']);
                if (count($quantitys) > 0) {
                    foreach ($quantitys as $key => $value) {
                        if (!empty($value) && $value > 0)
                            $error = false;
                    }
                }
            }
            //------------------------------------------------------------------
            if ($error === true)
                $model->addError('quantity', 'No hay cantidades ingresadas');
            echo CHtml::errorSummary($model);
            Yii::app()->end();
        }
    }
    
    /**
     * Metodo para guardar las compras 
     * 
     * @author Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2013 INGENEO S.A.S.
     * @license http://www.opensource.org/licenses/bsd-license.php  BSD License
     * @version Release: $Id$
     */
    private function _postSave(&$model){
        //Captura de datos Post ------------------------------------------------
        if (isset($_POST['Order'])) {            
            $defaultBranch = Yii::app()->purifier->purify($_POST['codeBranch']);
            $model->attributes = Yii::app()->purifier->purify($_POST['Order']);
            $model->ord_description = Yii::app()->purifier->purify(
                    $_POST['Order']['ord_description']
            );
            //Validacion de estado segun botones -------------------------------
            if (isset($_POST['status']) && $_POST['status'] === Order::STATUS_PENDING) {
                $model->ord_status = Order::STATUS_PENDING;
            } elseif (isset($_POST['status']) && $_POST['status'] === Order::STATUS_ALLOW) {
                $model->ord_status = Order::STATUS_ALLOW;
            } else {
                $model->ord_status = Order::STATUS_PARCIAL;
            }
            //------------------------------------------------------------------
            $model->ord_nit = Yii::app()->purifier->purify($_POST['codClient']);
            if (isset($_POST['type']) && $_POST['type'] === 'ref') {
                $model->ord_income_type = Order::TYPE_INCOME_FORM;
            } elseif (isset($_POST['type']) && $_POST['type'] === 'file') {
                $model->ord_income_type = Order::TYPE_INCOME_FILE;
            } else {
                $model->ord_income_type = Order::TYPE_INCOME_CATALOG;
            }
            $model->ord_codeBranch = $defaultBranch;
            $model->ord_user = Yii::app()->user->name;
            //------------------------------------------------------------------                        
            
            if ($model->validate()) {
                $quantitys = Yii::app()->purifier->purify($_POST['orp_amount']);
                if (count($quantitys) > 0) {
                    // Guardar los datos del pedido ----------------------------
                    $model->save();
                    //----------------------------------------------------------
                    $totalNeto = 0;
                    $totalNetoIva = 0;
                    $totalDiscount = 0;
                    $error = true; 
                    //Variable para indicar al vendedor en caso de no haber ----                    
                    foreach ($quantitys as $key => $value) {
                        if (!is_numeric($value)) {
                            $value = 0;
                        }                                                
                        if (!empty($value) && $value > 0) {
                            $error = false;
                            $undExist =  '';
                            $description = Yii::app()->purifier->purify($_POST[$key . '_description']);
                            $amountReq = Yii::app()->purifier->purify($_POST[$key . '_amount_request']);
                            $priceUnt = Yii::app()->purifier->purify($_POST[$key . '_unt_price']);
                            $priceUntIva = Yii::app()->purifier->purify($_POST[$key . '_unt_price_iva']);
                            $iva = Yii::app()->purifier->purify($_POST[$key . '_iva']);
                            $idCategory = Yii::app()->purifier->purify($_POST[$key . '_cat']);
                            //--------------------------------------------------
                            if(isset($_POST[$key . '_inv'])){
                                $undExist = (int)Yii::app()->purifier->purify($_POST[$key . '_inv']);
                            }                                                                                    
                            //--------------------------------------------------
                            $totalNeto += $value * $priceUnt;
                            $totalNetoIva += $value * $priceUntIva;
                            //--------------------------------------------------
                            $orderProduct = new OrderProduct;
                            $orderProduct->orp_ord_id = $model->ord_id;
                            $orderProduct->orp_reference = $key;
                            $orderProduct->orp_description = $description;
                            $orderProduct->orp_amount = $value;
                            $orderProduct->orp_amount_request = $amountReq;
                            $orderProduct->orp_iva = $iva;
                            $orderProduct->orp_price_iva = $priceUntIva;
                            $orderProduct->orp_und_exist = $undExist;
                            $orderProduct->orp_price_no_iva = $priceUnt;
                            $orderProduct->orp_total_iva = $value * $priceUntIva;
                            $orderProduct->orp_total_no_iva = $value * $priceUnt;
                            $orderProduct->orp_category_id = $idCategory;
                            $orderProduct->save();
                        }                        
                    }                                       
                    $totalIva = $totalNetoIva - $totalNeto;
                    $model->ord_total_net = $totalNeto;
                    $model->ord_total_iva = $totalIva;
                    $model->ord_total_discount = $totalDiscount;
                    $model->ord_total = $totalNetoIva;
                    $model->save();   
                    //Validamos el valor minimo del pedido ---------------------
//                    if($totalNeto < $model->getLimitOrder()){
//                        $model->ord_status = Order::STATUS_PENDING;
//                        $model->save();
//                        Yii::app()->user->setFlash(
//                                "error", 'El pedido no supera el valor mínimo ($'
//                                . number_format($model->getLimitOrder())
//                                .'). Pedido guardado en estado Pendiente');
//                        $url = Yii::app()->createUrl("/order/admin");
//                        $this->redirect($url);
//                        Yii::app()->end();
//                    }
                    //----------------------------------------------------------
                    if ($error) {
                        Yii::app()->user->setFlash(
                                "error", 'No hay cantidades ingresadas');
                        $model->delete();
                    } else {
                        //validamos si puede enviar  el peido por el presupuesto           
                        $infoBudget = $model->infoBudget($model->ord_nit, $model->ord_codeBranch);             
                        if($infoBudget['bloqueo'] == Budget::BLOQUEO_SI ){            
                            $totalAcumulado = $infoBudget['acumulado'] + $totalNetoIva;
                            if($totalAcumulado >= $infoBudget['presupuesto']){                
                                $model->ord_status = Order::STATUS_PARCIAL;
                                $model->save();
                                Yii::app()->user->setFlash(
                                        "error", 'La sucursal ha superado el presupuesto asignado. El pedido será guardado');
                                $url = Yii::app()->createUrl("/order/admin");
                                $this->redirect($url);
                                Yii::app()->end();
                            }            
                        }
                        
                        //Envio de correo a los pedidos aprobados --------------
                        if ($model->ord_status === Order::STATUS_ALLOW) {
                            $this->_saveOrderSiesa($model);                            
                            //--------------------------------------------------
                            $url = Yii::app()->createUrl("/order/admin");
                            $this->redirect($url);
                            Yii::app()->end();                            
                        }
                        //Notificacion al solicitar aprobacion -----------------
                        if ($model->ord_status === Order::STATUS_PENDING) {
                            $this->_sendMail($model, $model::STATUS_PENDING);
                        }
                        //Redireccion segun el boton ---------------------------
                        if (isset($_POST['status']) && $_POST['status'] === Order::ORDER_NEW) {
                            if (isset($_POST['type']) && $_POST['type'] === 'ref') {
                                $url = Yii::app()->createUrl("/order/createorder", array('type' => 'ref'));
                                $this->redirect($url);
                            }if (isset($_POST['type']) && $_POST['type'] === 'file') {
                                $url = Yii::app()->createUrl("/order/loadfile");
                                $this->redirect($url);
                            } else {
                                $url = Yii::app()->createUrl("/order/createorder");
                                $this->redirect($url);
                            }
                        } else {
                            $url = Yii::app()->createUrl("/order/admin");
                            $this->redirect($url);
                        }
                    }
                }
            }
        }
    }
    
    /**
     * Metodo para guardar las compras 
     * 
     * @author Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2013 INGENEO S.A.S.
     * @license http://www.opensource.org/licenses/bsd-license.php  BSD License
     * @version Release: $Id$
     */
    public function actionSavemultiorder(){
        //Captura de datos Post ------------------------------------------------
        $strError = '';
        $error =  false;
        if (isset($_POST['Order'])) { 
            $model = new Order;
            if (isset($_POST['ajax']) && $_POST['ajax'] === 'order-form') {
                $model->attributes = Yii::app()->purifier->purify($_POST['Order']);
                $model->scenario = 'createOrder';
                if(!$model->validate()){
                    echo CHtml::errorSummary($model);
                    Yii::app()->end();
                } 
            }
            
            $nit = Yii::app()->purifier->purify($_POST['codClient']); 
            $userAllow = null;
            //Validacion de estado segun botones -------------------------------
            if (isset($_POST['status']) && $_POST['status'] === Order::STATUS_PENDING) {
                $status = Order::STATUS_PARCIAL;
            } elseif (isset($_POST['status']) && $_POST['status'] === Order::STATUS_ALLOW) {
                $status = Order::STATUS_PENDING;
                $userAllow = Yii::app()->user->name;
            } else {
                $status = Order::STATUS_PARCIAL;
            }
            //Traemos todas las sucursales -------------------------------------
            $client = new Client;
            $listBranch = $client->getListBranch($nit);
            if (count($listBranch) > 0) {
                foreach ($listBranch as $codBranch => $branch) {
                    $tempModel = new Order;
                    $tempModel->attributes = $model->attributes;
                    $tempModel->ord_nit = $nit;
                    $tempModel->ord_codeBranch = $codBranch;
                    $tempModel->ord_income_type = Order::TYPE_INCOME_MULTI_BRANCH;
                    $tempModel->ord_description = Yii::app()->purifier->purify(
                            $_POST['Order']['ord_description']
                    );
                    $tempModel->ord_status = $status;
                    $tempModel->ord_user = Yii::app()->user->name;
                    $tempModel->ord_user_allow = $userAllow;
                    //Consultamos los item por cada ----------------------------
                    $listProd = ClientSiesa::getListProduct($nit, $codBranch);
                    $arrayProd = HelperFile::array_group_by($listProd, 'prd_reference');
                    $arrayTemp = CHtml::listData(
                            $listProd, 'prd_reference', 
                            'prd_reference');
                    $quantitys = Yii::app()->purifier->purify($_POST['orp_amount']);
                    
                    if (count($quantitys) > 0) {
                        // Guardar los datos del pedido ------------------------
                        $tempModel->save();
                        //------------------------------------------------------
                        $totalNeto = 0;
                        $totalNetoIva = 0;
                        $totalDiscount = 0;
                        foreach ($quantitys as $reference => $quanTBranchs) {
                            $quantity = $quanTBranchs[$branch];
                            if (!is_numeric($quantity)) {
                                $quantity = 0;
                            }                                                
                            if (!empty($quantity) && $quantity > 0 
                                    && in_array($reference, $arrayTemp)) {
                                $undExist =  '';
                                $description = Yii::app()->purifier->purify($_POST[$reference . '_description']);
                                $priceUnt = $arrayProd[$reference]['prd_unit_price'];
                                $priceUntIva = $arrayProd[$reference]['prd_unit_price_iva'];
                                $iva = $arrayProd[$reference]['prd_iva'];
                                $idCategory = Yii::app()->purifier->purify($_POST[$reference . '_cat']);
                                //--------------------------------------------------
                                if(isset($_POST[$reference . '_inv'])){
                                    $undExist = (int)Yii::app()->purifier->purify($_POST[$reference . '_inv']);
                                }                                                                                    
                                //--------------------------------------------------
                                $totalNeto += $quantity * $priceUnt;
                                $totalNetoIva += $quantity * $priceUntIva;
                                //--------------------------------------------------
                                $orderProduct = new OrderProduct;
                                $orderProduct->orp_ord_id = $tempModel->ord_id;
                                $orderProduct->orp_reference = $reference;
                                $orderProduct->orp_description = $description;
                                $orderProduct->orp_amount = $quantity;
                                $orderProduct->orp_amount_request = $quantity;
                                $orderProduct->orp_iva = $iva;
                                $orderProduct->orp_price_iva = $priceUntIva;
                                $orderProduct->orp_und_exist = $undExist;
                                $orderProduct->orp_price_no_iva = $priceUnt;
                                $orderProduct->orp_total_iva = $quantity * $priceUntIva;
                                $orderProduct->orp_total_no_iva = $quantity * $priceUnt;
                                $orderProduct->orp_category_id = $idCategory;
                                $orderProduct->save();
                            }
                        }
                        
                        if($totalNeto > 0){
                            $totalIva = $totalNetoIva - $totalNeto;
                            $tempModel->ord_total_net = $totalNeto;
                            $tempModel->ord_total_iva = $totalIva;
                            $tempModel->ord_total_discount = $totalDiscount;
                            $tempModel->ord_total = $totalNetoIva;
                            $tempModel->save(); 
                            
//                            if($totalNeto < $model->getLimitOrder()){
//                                $tempModel->ord_status = Order::STATUS_PENDING;
//                                $tempModel->save();
//                                $error =  true;
//                                $strError .= 'El pedido no supera el valor mínimo ($'
//                                    . number_format($model->getLimitOrder())
//                                    .'). Pedido No.('.$tempModel->ord_id
//                                    .') guardado en estado Pendiente'
//                                    . '</br>';
//                            }

                            //validamos si puede enviar  el peido por el presupuesto  
                            $infoBudget = $model->infoBudget($tempModel->ord_nit, $tempModel->ord_codeBranch); 
                            if($infoBudget['bloqueo'] == Budget::BLOQUEO_SI ){            
                                $totalAcumulado = $infoBudget['acumulado'] + $totalNetoIva;
                                if($totalAcumulado >= $infoBudget['presupuesto']){                
                                    $model->ord_status = Order::STATUS_PARCIAL;
                                    $model->save();
                                    $error =  true;
                                    $strError .= 'Sucursal: '.$branch
                                            . ' ha superado el presupuesto '
                                            . 'asignado. El pedido será guardado '
                                            . '</br>';
                                }            
                            }
                        }else{
                            $tempModel->delete();
                        }
                    }
                }
            }
            
            if($error){
                Yii::app()->user->setFlash(
                        "error", $strError);
            }else{
                //--------------------------------------------------------------
                Yii::app()->user->setFlash(
                        "success", 'Pedidos guardados con éxito');
            }
			//Ejecutamos la tarea en segundo plano -----------------------------
            exec(Yii::app()->params['commandMultibranch']);
            $url = Yii::app()->createUrl("/order/admin");
            echo '<script type="text/javascript">window.location.href="'.$url.'"; </script>';
            Yii::app()->end();
        }
    }

    /**
     * Creates a new model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     */
    public function actionCreateordersales() {
        $model = new Order;
        $client = new Client;
        $defaultBranch = '';
        $defaultClient = '';
        $listBranch = array();
        $totalIva = 0;
        $summary = false;
        $this->layout = '//layouts/column1';
// Uncomment the following line if AJAX validation is needed
//Validacion de campos -------------------------------------------------
        if (isset($_POST['ajax']) && $_POST['ajax'] === 'order-form') {

            $model->attributes = Yii::app()->purifier->purify($_POST['Order']);
            $model->scenario = 'createOrder';
            $model->validate();
            $error = true;
            if (isset($_POST['orp_amount'])) {
                $quantitys = Yii::app()->purifier->purify($_POST['orp_amount']);
                if (count($quantitys) > 0) {
                    foreach ($quantitys as $key => $value) {
                        if (!empty($value) && $value > 0)
                            $error = false;
                    }
                }
            }

            if ($error === true)
                $model->addError('quantity', 'No hay cantidades ingresadas');
            echo CHtml::errorSummary($model);
            Yii::app()->end();
        }
        //----------------------------------------------------------------------
        $idUser = User::getId();
        $listClient = $client->getListClientSave($idUser);
        if (count($listClient) > 0) {
            $defaultClient = key($listClient);
        }

        $listBranch = $client->getListBranch($defaultClient);
        if (count($listBranch) > 0) {
            if (empty($defaultBranch))
                $defaultBranch = key($listBranch);
        }

        //Captura de datos Post ------------------------------------------------
        if (isset($_POST['Order'])) {
            $defaultBranch = Yii::app()->purifier->purify($_POST['codeBranch']);
            $model->attributes = Yii::app()->purifier->purify($_POST['Order']);
            $model->ord_description = Yii::app()->purifier->purify(
                    $_POST['Order']['ord_description']
            );
            //Validacion de estado segun botones -------------------------------
            if (isset($_POST['status']) && $_POST['status'] === Order::STATUS_PENDING) {
                $model->ord_status = Order::STATUS_PENDING;
            } elseif (isset($_POST['status']) && $_POST['status'] === Order::STATUS_ALLOW) {
                $model->ord_status = Order::STATUS_ALLOW;
            } else {
                $model->ord_status = Order::STATUS_PARCIAL;
            }

            $model->ord_nit = Yii::app()->purifier->purify($_POST['codClient']);
            if (isset($_POST['type']) && $_POST['type'] === 'ref') {
                $model->ord_income_type = Order::TYPE_INCOME_FORM;
            } elseif (isset($_POST['type']) && $_POST['type'] === 'file') {
                $model->ord_income_type = Order::TYPE_INCOME_FILE;
            } else {
                $model->ord_income_type = Order::TYPE_INCOME_CATALOG;
            }
            $model->ord_codeBranch = $defaultBranch;
            $model->ord_user = Yii::app()->user->name;

            if ($model->validate()) {
                $quantitys = Yii::app()->purifier->purify($_POST['orp_amount']);
                if (count($quantitys) > 0) {
                    // Guardar los datos del pedido ----------------------------
                    $model->save();
                    //----------------------------------------------------------
                    $totalNeto = 0;
                    $totalNetoIva = 0;
                    $totalDiscount = 0;
                    $error = true;
                    foreach ($quantitys as $key => $value) {
                        if (!is_numeric($value)) {
                            $value = 0;
                        }

                        if (!empty($value) && $value > 0) {
                            $error = false;
                            $description = Yii::app()->purifier->purify(
                                    $_POST[$key . '_description']
                            );
                            $amountReq = Yii::app()->purifier->purify(
                                    $_POST[$key . '_amount_request']
                            );
                            $priceUnt = Yii::app()->purifier->purify(
                                    $_POST[$key . '_unt_price']
                            );
                            $priceUntIva = Yii::app()->purifier->purify(
                                    $_POST[$key . '_unt_price_iva']
                            );
                            $iva = Yii::app()->purifier->purify(
                                    $_POST[$key . '_iva']
                            );
                            $idCategory = Yii::app()->purifier->purify(
                                    $_POST[$key . '_cat']
                            );

                            $totalNeto += $value * $priceUnt;
                            $totalNetoIva += $value * $priceUntIva;

                            $orderProduct = new OrderProduct;
                            $orderProduct->orp_ord_id = $model->ord_id;
                            $orderProduct->orp_reference = $key;
                            $orderProduct->orp_description = $description;
                            $orderProduct->orp_amount = $value;
                            $orderProduct->orp_amount_request = $amountReq;
                            $orderProduct->orp_iva = $iva;
                            $orderProduct->orp_price_iva = round($priceUntIva);
                            $orderProduct->orp_price_no_iva = round($priceUnt);
                            $orderProduct->orp_total_iva = round($value * $priceUntIva);
                            $orderProduct->orp_total_no_iva = round($value * $priceUnt);
                            $orderProduct->orp_category_id = $idCategory;

                            if (!$orderProduct->save()) {
                                //----------------------------------------------------
                                Yii::log(__FILE__ . ':' . __LINE__ . ':' . __FUNCTION__ . ':'
                                        . ' {' . print_r($orderProduct, true) . '}', CLogger::LEVEL_ERROR, 'b2b.db');
                                //---------------------------------------------------
                                //----------------------------------------------------
                                Yii::log(__FILE__ . ':' . __LINE__ . ':' . __FUNCTION__ . ':'
                                        . ' {' . print_r($orderProduct->getErrors(), true) . '}', CLogger::LEVEL_ERROR, 'b2b.db');
                                //---------------------------------------------------
                            }
                        }
                    }
                    $totalIva = $totalNetoIva - $totalNeto;
                    $model->ord_total_net = round($totalNeto);
                    $model->ord_total_iva = round($totalIva);
                    $model->ord_total_discount = round($totalDiscount);
                    $model->ord_total = round($totalNetoIva);
                    if (!$model->save()) {
                        //----------------------------------------------------
                        Yii::log(__FILE__ . ':' . __LINE__ . ':' . __FUNCTION__ . ':'
                                . ' {' . print_r($model, true) . '}', CLogger::LEVEL_ERROR, 'b2b.db');
                        //---------------------------------------------------
                        //----------------------------------------------------
                        Yii::log(__FILE__ . ':' . __LINE__ . ':' . __FUNCTION__ . ':'
                                . ' {' . print_r($model->getErrors(), true) . '}', CLogger::LEVEL_ERROR, 'b2b.db');
                        //---------------------------------------------------
                    }

                    if ($error) {
                        Yii::app()->user->setFlash(
                                "error", 'No hay cantidades ingresadas');
                        $model->delete();
                    } else {
                        //Envio de correo a los pedidos aprobados --------------
                        if ($model->ord_status === Order::STATUS_ALLOW) {
                            $this->_saveOrderSiesa($model, true);
                            $url = Yii::app()->createUrl("/order/admin");
                            $this->redirect($url);
                            Yii::app()->end();
                        }
                        //Notificacion al solicitar aprobacion -----------------
                        if ($model->ord_status === Order::STATUS_PENDING) {
                            $this->_sendMail($model, $model::STATUS_PENDING);
                        }
                        //Redireccion segun el boton ---------------------------
                        if (isset($_POST['status']) && $_POST['status'] === Order::ORDER_NEW) {
                            if (isset($_POST['type']) && $_POST['type'] === 'ref') {
                                $url = Yii::app()->createUrl("/order/createorder", array('type' => 'ref'));
                                $this->redirect($url);
                            }if (isset($_POST['type']) && $_POST['type'] === 'file') {
                                $url = Yii::app()->createUrl("/order/loadfile");
                                $this->redirect($url);
                            } else {
                                $url = Yii::app()->createUrl("/order/createorder");
                                $this->redirect($url);
                            }
                        } else {
                            $url = Yii::app()->createUrl("/order/admin");
                            $this->redirect($url);
                        }
                    }
                }
            }
        }

        $this->render('createOrderSales', array(
            'model' => $model,
            'listBranch' => $listBranch,
            'listClient' => $listClient,
            'defaultBranch' => $defaultBranch,
            'defaultClient' => $defaultClient,
            'totalIva' => $totalIva,
            'summary' => $summary,
        ));
    }

    /**
     * Accion para la adicion de productos al momento de liquidar 
     * un pedido
     * 
     * @return string
     */
    public function actionAddproducts() {
        $this->layout = '//layouts/column3';
        if (isset($_POST['idOrder']) && is_numeric($_POST['idOrder'])) {
            $listReference = array();
            $idOrder = Yii::app()->purifier->purify($_POST['idOrder']);
            $arrayReference = Yii::app()->purifier->purify($_POST['arrayReference']);
            if (count($arrayReference) > 0) {
                foreach ($arrayReference as $value) {
                    $jsonDecode = json_decode($value);
                    $listReference[$jsonDecode->reference] = array(
                        'iden' => $jsonDecode->iden,
                        'quantity' => $jsonDecode->quantity,
                        'iva' => $jsonDecode->iva,
                        'price' => $jsonDecode->price,
                        'priceIva' => $jsonDecode->priceIva
                    );
                }
            }
            $model = $this->loadModel($idOrder);
            $nit = $model->ord_nit;
            $codeBranch = $model->ord_codeBranch;
            $listProduct = ClientSiesa::getListProduct($nit, $codeBranch);
            $listCategory = ClientSiesa::getLisCategory();
            
            $RolFranquicias = Yii::app()->params['RolFranquicias'];
            if(Yii::app()->user->checkAccess($RolFranquicias)){
                $this->renderPartial('_addproductsFran', array(
                'listProduct' => $listProduct,
                'arrayReference' => $arrayReference,
                'listCategory' => $listCategory,
                'listReference' => $listReference,
                    ), false, true);
            }else{
                $this->renderPartial('_addproducts', array(
                'listProduct' => $listProduct,
                'arrayReference' => $arrayReference,
                'listCategory' => $listCategory,
                'listReference' => $listReference,
                    ), false, true);
            }                        
        }
        return '';
    }

    /**
     * Funcion que permite el cambio de botones
     */
    public function actionChangebuttom() {
        $this->layout = '//layouts/column3';
        if (isset($_POST['type']) && $_POST['type'] === 'liquidar') {
            $this->renderPartial('_buttomLiquidar', true, false);
        } elseif (isset($_POST['type']) && $_POST['type'] === 'manageLiquidate') {
            $idOrder = Yii::app()->purifier->purify($_POST['idOrder']);
            $this->render('_buttonAdminLiquidate', array('idOrder' => $idOrder));
        } else {
            $this->render('_buttomSend');
        }
    }

    /**
     * Metodo que permite obtener el listado de los productos 
     * segun el nit y la sucursarl
     * @param array $_POST 
     * @return string 
     */
    public function actionGetproducts() {
        $this->layout = '//layouts/column3';
        $orderProduct = new OrderProduct;
        $model = new Order;
        $listProduct = array();
        $nit = "";
        if (isset($_POST['codeBranch'])) {
            $nit = Yii::app()->purifier->purify($_POST['nit']);
            $codeBranch = Yii::app()->purifier->purify($_POST['codeBranch']);
            $listProduct = ClientSiesa::getListProduct($nit, $codeBranch);
        }
        //----------------------------------------------------------------------
        $RolFranquicias = Yii::app()->params['RolFranquicias'];
        //----------------------------------------------------------------------
        if (isset($_POST['type']) && $_POST['type'] === 'ref') {
            if(Yii::app()->user->checkAccess($RolFranquicias)){
                $this->renderPartial('_formProductsRefFran', array(
                    'model' => $model,
                    'listProduct' => $listProduct,
                    'orderProduct' => $orderProduct,
                        ), false, true);
            }else{
                $this->renderPartial('_formProductsRef', array(
                    'model' => $model,
                    'listProduct' => $listProduct,
                    'orderProduct' => $orderProduct,
                        ), false, true);
            }            
        } elseif(Yii::app()->user->checkAccess($RolFranquicias)){
            $listCategory = ClientSiesa::getLisCategory($nit);
            $this->renderPartial('_formProductsFran', array(
                'model' => $model,
                'listProduct' => $listProduct,
                'orderProduct' => $orderProduct,
                'listCategory' => $listCategory,
                    ), false, true);
        }elseif (isset($_POST['type']) && $_POST['type'] === 'sales') {
            $listCategory = ClientSiesa::getLisCategory($nit);
            $this->renderPartial('_formProductsSales', array(
                'model' => $model,
                'listProduct' => $listProduct,
                'orderProduct' => $orderProduct,
                'listCategory' => $listCategory,
                    ), false, true);
        } else {
            $listCategory = ClientSiesa::getLisCategory($nit);
            $this->renderPartial('_formProducts', array(
                'model' => $model,
                'listProduct' => $listProduct,
                'orderProduct' => $orderProduct,
                'listCategory' => $listCategory,
                    ), false, true);
        }
    }

    /**
     * funcion para validar el cupo de
     * cada sucursal
     */
    public function actionValidateQuotaBranch() {
        $this->layout = '//layouts/column3';
        if (isset($_POST['codeBranch'])) {
            $nit = Yii::app()->purifier->purify($_POST['nit']);
            $codeBranch = Yii::app()->purifier->purify($_POST['codeBranch']);
            $infoBranch = ClientSiesa::validateQuota($nit, $codeBranch);
            //var_dump($infoBranch); exit;
            $response = new stdClass();
            $response->error = false;
            $response->msg = '';

            if (isset($infoBranch['cupo']) && $infoBranch['cupo'] == 1 && isset($infoBranch['mora']) && $infoBranch['mora'] == 1) {
                Yii::app()->user->setFlash(
                        "error", 'Señor usuario esta sucursal se encuentra <strong>sin cupo
					</strong> y <strong> en mora</strong>,
                    usted podrá crear el pedido pero este quedara retenido
                    hasta que contacte con su asesor comercial');
                $response->error = true;
                $response->msg = $this->renderPartial('_errorQuota', '', true, false);
            } elseif (isset($infoBranch['cupo']) && $infoBranch['cupo'] == 1) {
                Yii::app()->user->setFlash(
                        "error", 'Señor usuario esta sucursal se encuentra <strong>sin cupo
					</strong>, usted podrá crear el pedido pero este quedara 
					retenido hasta que contacte con su asesor comercial');
                $response->error = true;
                $response->msg = $this->renderPartial('_errorQuota', '', true, false);
            } elseif (isset($infoBranch['mora']) && $infoBranch['mora'] == 1) {
                Yii::app()->user->setFlash(
                        "error", 'Señor usuario esta sucursal se encuentra <strong>en mora</strong>,
                    usted podrá crear el pedido pero este quedara retenido
                    hasta que contacte con su asesor comercial');
                $response->error = true;
                $response->msg = $this->renderPartial('_errorQuota', '', true, false);
            }
            echo json_encode($response);
        }
    }

    /**
     * funcion para validar el presupuesto de
     * cada sucursal
     */
    public function actionValidateBudget() {
        $this->layout = '//layouts/column3';
        if (isset($_POST['codeBranch'])) {
            $nit = Yii::app()->purifier->purify($_POST['nit']);
            $codeBranch = Yii::app()->purifier->purify($_POST['codeBranch']);
            $order = new Order;            
            $infoBudget = $order->infoBudget($nit, $codeBranch);             
                        
            $response = new stdClass();
            $response->presupuesto = $infoBudget['presupuesto'];
            $response->bloqueo_pedidos =  $infoBudget['bloqueo_pedidos'];
            $response->bloqueo =  $infoBudget['bloqueo'];
            $response->acumulado =  $infoBudget['acumulado'];
            $response->error = false;
            $response->msg = '';

            if ($infoBudget['bloqueo_pedidos'] == Budget::BLOQUEO_SI) {
                Yii::app()->user->setFlash(
                        "error", 'La sucursal ha completado el presupuesto '
                        . 'asignado');
                $response->error = true;
                $response->msg = $this->renderPartial('_errorQuota', '', true, false);
            } 
            echo json_encode($response);
        }
    }
    
    /**
     * Metodo que permite obtener el listado de los productos 
     * segun el nit y la sucursarl
     * @param array $_POST 
     * @return string 
     */
    public function actionUpdateproducts() {
        $this->layout = '//layouts/column3';
        if (isset($_POST['idOrder'])) {            
            $idOrder = Yii::app()->purifier->purify($_POST['idOrder']);
            $orderProduct = new OrderProduct;
            $listProduct = $orderProduct->getProducts($idOrder);  
            
            $RolFranquicias = Yii::app()->params['RolFranquicias'];
            if(Yii::app()->user->checkAccess($RolFranquicias)){
                $this->renderPartial('_liquidateProductsFran', array(
                'listProduct' => $listProduct,
                    ), false, true);
            }else{
                $this->renderPartial('_liquidateProducts', array(
                'listProduct' => $listProduct,
                    ), false, true);
            }                        
        }
    }

    /**
     * Metodo para guardar la orden 
     * @param type $id
     */
    public function actionSaveorder($id) {
//Carga modelo Order                
        $model = $this->loadModel($id);
//Validacion ajax-------------------------------------------------------
        if (isset($_POST['ajax']) && $_POST['ajax'] === 'order-form') {
            $model->attributes = Yii::app()->purifier->purify($_POST['Order']);
            $model->scenario = 'createOrder';
            $model->validate();

            $error = true;
            if (isset($_POST['orp_amount'])) {
                $quantitys = Yii::app()->purifier->purify($_POST['orp_amount']);
                if (count($quantitys) > 0) {
                    foreach ($quantitys as $key => $value) {
                        if (!empty($value) && $value > 0) {
                            $error = false;
                        }
                    }
                }
            }

            if ($error === true) {
                $model->addError('quantity', 'No hay cantidades ingresadas');
            }
            echo CHtml::errorSummary($model);
            Yii::app()->end();
        }
        //----------------------------------------------------------------------        
        if (isset($_POST['orp_amount'])) {

            $quantitys = Yii::app()->purifier->purify($_POST['orp_amount']);
            if (count($quantitys) > 0) {
                // Inicializacion de variables ---------------------------------
                $totalNeto = 0;
                $totalNetoIva = 0;
                $totalDiscount = 0;                
                //Borramos los items -------------------------------------------                
                $itemsActuales = array_keys($quantitys);
                OrderProduct::model()->deleteAll("orp_ord_id=".$model->ord_id
                        . " AND orp_id NOT IN('"
                        . implode("','", $itemsActuales)."')");
                foreach ($quantitys as $key => $value) {
                    if (!is_numeric($value)) {
                        $value = 0;
                    }                      
                    //Actualizacion para todos los items -----------------------
                    if (!empty($value) && $value > 0) {
                        //Validacion productos nuevos --------------------------
                        $newProduct = false;
                        $undExist = '';
                        if (strstr($key, '-')) {
                            $newProduct = true;
                            $description = Yii::app()->purifier->purify(
                                    $_POST[$key . '_description']
                            );
                            $iva = Yii::app()->purifier->purify(
                                    $_POST[$key . '_iva']
                            );
                            $idCategory = Yii::app()->purifier->purify(
                                    $_POST[$key . '_cat']
                            );
                            $orderProduct = new OrderProduct;
                            $orderProduct->orp_description = $description;
                            $orderProduct->orp_reference = str_replace('-', '', $key);
                            $orderProduct->orp_iva = $iva;
                            $orderProduct->orp_ord_id = $model->ord_id;
                            $orderProduct->orp_category_id = $idCategory;
                        } else {
                            //Carga de productos existentes ------------------------ 
                            $orderProduct = OrderProduct::model()->findByPk($key);
                            $undExist = $orderProduct->orp_und_exist;
                        }

                        $amountReq = Yii::app()->purifier->purify(
                                $_POST[$key . '_amount_request']
                        );                                                
                        $priceUnt = Yii::app()->purifier->purify(
                                $_POST[$key . '_unt_price']
                        );
                        $priceUntIva = Yii::app()->purifier->purify(
                                $_POST[$key . '_unt_price_iva']
                        );
                        if(isset($_POST[$key . '_inv'])){
                            $undExist = Yii::app()->purifier->purify(
                                    $_POST[$key . '_inv']
                            );
                        }                        

                        $totalNeto += $value * $priceUnt;
                        $totalNetoIva += $value * $priceUntIva;
                        $orderProduct->orp_amount = $value;
                        $orderProduct->orp_amount_request = $amountReq;
                        $orderProduct->orp_und_exist = $undExist;
                        $orderProduct->orp_price_iva = $priceUntIva;
                        $orderProduct->orp_price_no_iva = $priceUnt;
                        $orderProduct->orp_total_iva = $value * $priceUntIva;
                        $orderProduct->orp_total_no_iva = $value * $priceUnt;
                        $orderProduct->save();
                    } else {
                        //Eliminacion si se cambio la cantidad del producto ----                       
                        if (!strstr($key, '-')) {
                            $orderProduct = OrderProduct::model()->findByPk($key);
                            $orderProduct->delete();
                        }
                    }
                }
                $model->attributes = Yii::app()->purifier->purify($_POST['Order']);
                $totalIva = $totalNetoIva - $totalNeto;
                $model->ord_total_net = $totalNeto;
                $model->ord_total_iva = $totalIva;
                $model->ord_total_discount = $totalDiscount;
                $model->ord_total = $totalNetoIva;
                //Validamos el valor minimo del pedido ---------------------
//                if($totalNeto < $model->getLimitOrder()){
//                    $model->ord_status = Order::STATUS_PENDING;
//                    $model->save();
//                    Yii::app()->user->setFlash(
//                            "error", 'El pedido no supera el valor mínimo ($'
//                            . number_format($model->getLimitOrder())
//                            .'). Pedido guardado en estado Pendiente');
//                    $url = Yii::app()->createUrl("/order/admin");
//                    $this->redirect($url);
//                    Yii::app()->end();
//                }
            }
        } else {
            $model->addError('quantity', 'A ocurrido un error inténtelo mas tarde');
        }
//Verificacion de estado segun el boton presionado ---------------------
        switch (isset($_GET['status'])) {
            case (isset($_GET['status']) && $_GET['status'] === Order::STATUS_PENDING):
                $model->ord_status = Order::STATUS_PENDING;
                break;
            case (isset($_GET['status']) && $_GET['status'] === Order::STATUS_ALLOW):
                $model->ord_status = Order::STATUS_ALLOW;
                $model->ord_user_allow = Yii::app()->user->name;
                break;
            default:
                $model->ord_status = Order::STATUS_PARCIAL;
                break;
        }

        //Guardamos datos de la orden ------------------------------------------
        $model->save();
        //validamos si puede enviar  el peido por el presupuesto           
        $infoBudget = $model->infoBudget($model->ord_nit, $model->ord_codeBranch);        
        if($infoBudget['bloqueo'] == Budget::BLOQUEO_SI ){            
            $totalAcumulado = $infoBudget['acumulado'] + $totalNetoIva;
            if($totalAcumulado >= $infoBudget['presupuesto']){                
                $model->ord_status = Order::STATUS_PARCIAL;
                $model->ord_user_allow = null;
                $model->save();
                Yii::app()->user->setFlash(
                        "error", 'La sucursal ha superado el presupuesto asignado. El pedido será guardado');
                $url = Yii::app()->createUrl("/order/admin");
                $this->redirect($url);
                Yii::app()->end();
            }            
        }        
        //Envio de correo al aprovar el pedido ---------------------------------
        if (isset($_GET['status']) && $_GET['status'] === Order::STATUS_ALLOW) {
            //Consumo de servicio Siesa-----------------------------------------  
            $this->_saveOrderSiesa($model);                       
            //------------------------------------------------------------------
            $url = Yii::app()->createUrl("/order/admin");
            $this->redirect($url);
            Yii::app()->end();
        }
        //Envio de correo al solicitar aprovacion ------------------------------
        if (isset($_GET['status']) && $_GET['status'] === Order::STATUS_PENDING) {
            $this->_sendMail($model, $model::STATUS_PENDING);
        }
        //Redireccionamientos --------------------------------------------------
        $url = Yii::app()->createUrl("/order/admin");
        $this->redirect($url);
    }

    /**
     * Metodo para la almacenar pedidos 
     * mediante la carga de archivos
     */
    public function actionLoadfile() {
        $this->layout = '//layouts/column1';
        $model = new Order;
        $client = new Client;
        $defaultBranch = '';
        $defaultClient = '';
        $helpLoadFile = new HelperFile;

        $idUser = User::getId();
        $listClient = $client->getListClientSave($idUser);
        if (count($listClient) > 0) {
            $defaultClient = key($listClient);
        }

        $listBranch = $client->getListBranch($defaultClient);
        if (count($listBranch) > 0) {
            if (empty($defaultBranch)) {
                $defaultBranch = key($listBranch);
            }
        }

        if (isset($_GET['ajax']) && $_GET['ajax'] === 'download') {
            $nit = Yii::app()->purifier->purify($_GET['nit']);
            $codeBranch = Yii::app()->purifier->purify($_GET['codeBranch']);
            $listProductDB = ClientSiesa::getListProduct($nit, $codeBranch);
            if (count($listProductDB) > 0) {
                $headers = array(
                    'prd_reference' => 'Referencia',
                    'prd_description' => 'Descripción',
                    'prd_amount' => 'Cantidad'
                );
                $nameFile = 'Catálogo-' . $nit . '-' . $codeBranch;
                $arrayItems = array();
                foreach ($listProductDB as $key => $item) {
                    $arrayItems[] = array(
                        'prd_reference' => $item['prd_reference'],
                        'prd_description' => $item['prd_description'],
                        'prd_amount' => ' '
                    );
                }

                if (isset($_GET['type']) && $_GET['type'] === 'excel') {
                    $helpLoadFile->downFileExcel($nameFile, $headers, $arrayItems);
                } elseif (isset($_GET['type']) && $_GET['type'] === 'text') {
                    $helpLoadFile->downFileText($nameFile, $headers, $arrayItems);
                }
            }
            return false;
            Yii::app()->end();
        }

        if (isset($_GET['Order']['uploadFile'])) {
            $nit = Yii::app()->purifier->purify($_GET['nit']);
            $codeBranch = Yii::app()->purifier->purify($_GET['codeBranch']);
            $error = false;
            $strError = '';
            $contFile = array();
            $dataFile = array();

            $listProductDB = ClientSiesa::getListProduct($nit, $codeBranch);
            $listRef = array();
            if (count($listProductDB) > 0) {
                foreach ($listProductDB as $key => $value) {
                    $listRef[$value['prd_reference']] = $key;
                }
            } else {
                echo json_encode(array(
                'error' => 'Error al cargar el archivo',
                'msgError' => 'No se encontraron productos relacionados'));
                Yii::app()->end();
            }

            $fileData = CUploadedFile::getInstance($model, 'uploadFile');
            $fileType = $fileData->getType();
            $fileName = $fileData->getTempName();

            if ($fileType === 'text/plain' 
                    || $fileType === 'application/vnd.ms-excel' 
                    || $fileType === 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet') {
                try {
                    if ($fileType === 'text/plain') {
                        $file = fopen($fileName, 'r');
                        if ($file) {
                            while (!feof($file)) {
                                $line = fgets($file);
                                if (!empty($line))
                                    $contFile[] = utf8_encode($line);
                            }
                            fclose($file);
                        } else {
                            $strError .= 'Error al cargar el archivo "'
                                    . $fileName . '"';
                            $error = true;
                        }
                        if (count($contFile) > 0) {
                            foreach ($contFile as $value) {
                                $dataFile[] = explode(';', $value);
                            }
                        }
                    } else {
                        $dataFile = Yii::app()->yexcel->readActiveSheet(
                                $fileName, false);
                    }

                    $countFila = 2;
                    $listProduct = array();
                    if (count($dataFile) > 0) {
                        array_shift($dataFile);
                        foreach ($dataFile as $data) {
                            //Valido que las filas tengan 3 campo (Ref, Desc, Cant)-
                            if (count($data) != 3 && !empty($data)) {
                                $strError .= '<strong>Fila: </strong> '
                                        . $countFila
                                        . ' <strong>Msg: </strong> La fila no '
                                        . 'tiene la extructura esperada <br/>';
                                $error = true;
                            } else {
                                //Validamos la referencia ----------------------
                                $data[0] = trim((int) $data[0]);
                                $data[2] = trim($data[2]);
                                if (!isset($data[0])) {
                                    $msg = 'El campo no esta definido';
                                    $strError .= $helpLoadFile->makeMsg(
                                            $countFila, 'Referencia', $msg);
                                    $error = true;
                                } elseif (!is_numeric($data[0])) {
                                    $msg = 'El valor "'
                                            . $data[0]
                                            . '" no es numérico';
                                    $strError .= $helpLoadFile->makeMsg(
                                            $countFila, 'Referencia', $msg);
                                    $error = true;
                                } elseif (!array_key_exists($data[0], $listRef)) {
                                    $msg = 'La referencia "' . $data[0]
                                            . '" no es '
                                            . '" permitida ';
                                    $strError .= $helpLoadFile->makeMsg(
                                            $countFila, 'Referencia', $msg);
                                    $error = true;
                                }
                                //Validamos la descripcion----------------------
                                if (!isset($data[1]) || empty($data[1])) {
                                    $msg = 'El campo no esta definido';
                                    $strError .= $helpLoadFile->makeMsg(
                                            $countFila, 'Descripción', $msg);
                                    $error = true;
                                }
                                //Validamos la cantidad ------------------------                                                     
                                if (!isset($data[2])) {
                                    $msg = 'El campo no esta definido';
                                    $strError .= $helpLoadFile->makeMsg(
                                            $countFila, 'Cantidad', $msg);
                                    $error = true;
                                } elseif (preg_match('/[A-Za-z]/', $data[2])) {
                                    $msg = 'El valor "'
                                            . $data[2]
                                            . '" debe ser numérico mayor a cero(0)';
                                    $strError .= $helpLoadFile->makeMsg(
                                            $countFila, 'Cantidad', $msg);
                                    $error = true;
                                } elseif (is_numeric($data[2]) && strlen($data[2]) > 9) {
                                    $msg = 'El valor "'
                                            . $data[2]
                                            . '" es muy grande';
                                    $strError .= $helpLoadFile->makeMsg(
                                            $countFila, 'Cantidad', $msg);
                                    $error = true;
                                }

                                if (isset($data[0]) && array_key_exists($data[0], $listRef) && isset($data[1]) && isset($data[2]) && is_numeric($data[2]) && $data[2] >= 1) {
                                    $dataId = $listRef[$data[0]];
                                    $dataProduct = $listProductDB[$dataId];
                                    $dataProduct['prd_amount'] = $data[2];
                                    $listProduct[$data[0]] = $dataProduct;
                                }
                            }
                            $countFila++;
                        }
                    }
                } catch (Exception $exc) {
                    $error = true;
                    //----------------------------------------------------------
                    Yii::log(__FILE__ . ':' . __LINE__ . ':' . __FUNCTION__
                            . ':' . ' { ' . $exc->getMessage() . '}', CLogger::LEVEL_ERROR, 'b2b.file');
                    //----------------------------------------------------------
                }
            }
            //Respuesta --------------------------------------------------------
            if ($error) {
                echo json_encode(
                        array(
                            'error' => 'Error al cargar el archivo',
                            'msgError' => $strError));
            } else {
                $RolFranquicias = Yii::app()->params['RolFranquicias'];
                if(Yii::app()->user->checkAccess($RolFranquicias)){
                    $html = $this->renderPartial('_formProductsLoadFileFran', array(
                    'listProduct' => $listProduct
                        ), true, false);
                }else{
                    $html = $this->renderPartial('_formProductsLoadFile', array(
                    'listProduct' => $listProduct
                        ), true, false);
                }                
                echo json_encode(array('success' => 'true', 'html' => $html));
            }
            Yii::app()->end();

            $model->attributes = $_POST['Order'];
            if ($model->save()) {
                $this->redirect(array('view', 'id' => $model->ord_id));
            }
        }

        $this->render('loadfile', array(
            'model' => $model,
            'listBranch' => $listBranch,
            'listClient' => $listClient,
            'defaultBranch' => $defaultBranch,
            'defaultClient' => $defaultClient,
        ));
    }
    
    /**
     * Metodo para la almacenar pedidos 
     * mediante la carga de archivos
     */
    public function actionLoadfilemultibranch() {
		$this->layout = '//layouts/column1';
        $model = new Order;
        $client = new Client;
        $defaultBranch = '';
        $defaultClient = '';
        $helpLoadFile = new HelperFile;

        $idUser = User::getId();
        $listClient = $client->getListClientSave($idUser);
        if (count($listClient) > 0) {
            $defaultClient = key($listClient);
        }

        $listBranch = $client->getListBranch($defaultClient);
        if (count($listBranch) > 0) {
            if (empty($defaultBranch)) {
                $defaultBranch = key($listBranch);
            }
        }

        if (isset($_GET['ajax']) && $_GET['ajax'] === 'download') {
            $nit = Yii::app()->purifier->purify($_GET['nit']);
            $listBranch = $client->getListBranch($nit);
            if (count($listBranch) > 0) {
                if (empty($defaultBranch)) {
                    $defaultBranch = key($listBranch);
                }
            }

            $branchs = array_keys($listBranch);
            $listProductDB = ClientSiesa::getListAllProduct($nit, $branchs);
            if (count($listProductDB) > 0) {
                $headers = array(
                    'prd_reference' => 'Referencia',
                    'prd_description' => 'Descripción',
                );
                $headers  = array_merge($headers, $listBranch);
                $nameFile = 'Catálogo-' . $nit;
                $arrayItems = array();
                foreach ($listProductDB as $key => $item) {
                    $arrayItems[] = array(
                        'prd_reference' => $item['prd_reference'],
                        'prd_description' => $item['prd_description'],
                    );
                }

                if (isset($_GET['type']) && $_GET['type'] === 'excel') {
                    $helpLoadFile->downFileExcel($nameFile, $headers, $arrayItems);
                } elseif (isset($_GET['type']) && $_GET['type'] === 'text') {
                    $helpLoadFile->downFileText($nameFile, $headers, $arrayItems);
                }
            }else {
                $headers = array(
                    'prd_reference' => 'Referencia',
                    'prd_description' => 'Descripción',
                );
                $headers  = array_merge($headers, $listBranch);
                $nameFile = 'Catálogo-' . $nit;
                $arrayItems[] = array(
                        'prd_reference' => 'No items asociados'
                    );

                if (isset($_GET['type']) && $_GET['type'] === 'excel') {
                    $helpLoadFile->downFileExcel($nameFile, $headers, $arrayItems);
                } elseif (isset($_GET['type']) && $_GET['type'] === 'text') {
                    $helpLoadFile->downFileText($nameFile, $headers, $arrayItems);
                }
            }
            return false;
            Yii::app()->end();
        }

        if (isset($_GET['Order']['uploadFile'])) {
            $nit = Yii::app()->purifier->purify($_GET['nit']);
            $listBranch = $client->getListBranch($nit);
            if (count($listBranch) > 0) {
                if (empty($defaultBranch)) {
                    $defaultBranch = key($listBranch);
                }
            }
            $error = false;
            $strError = '';
            $contFile = array();
            $dataFile = array();
            $listRef = array();

            $fileData = CUploadedFile::getInstance($model, 'uploadFile');
            $fileType = $fileData->getType();
            $fileName = $fileData->getTempName();

            if ($fileType === 'text/plain' 
                    || $fileType === 'application/vnd.ms-excel' 
                    || $fileType === 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet') {
                try {
                    
                    $dataFile = Yii::app()->yexcel->readActiveSheet(
                            $fileName, false);
                    $branchs = array_keys($listBranch);
                    $listProductDB = ClientSiesa::getListAllProduct($nit, $branchs);
                    if (count($listProductDB) > 0) {
                        foreach ($listProductDB as $key => $value) {
                            $listRef[$value['prd_reference']] = $key;
                        }
                    } else {
                        echo json_encode(
                        array(
                            'error' => 'Error al cargar el archivo',
                            'msgError' => 'No se encontraron productos relacionados'));
                        Yii::app()->end();
                    }
                    
                    //Consultamso todas las listas de precios 
                    $listProducBran = [];
                    $dataBranchs = [];
                    foreach ($listBranch as $codeBranch => $branch) {
                        $listProdEachBranch = ClientSiesa::getListProduct($nit, $codeBranch);
                        foreach ($listProdEachBranch as $temp) {
                            $dataBranchs[$temp['prd_reference']] = $temp;
                        }
                        $arrayTemp = CHtml::listData( $listProdEachBranch, 
                                'prd_reference','prd_reference');
                        $listProducBran[$branch] = $arrayTemp;
                        
                    }
                                            
                    $countFila = 2;
                    $listProduct = array();
                    if (count($dataFile) > 0) {
                        $arrayHeader = $dataFile[0];
                        //Validamos las cabeceras 
                        $headers = array(
                            'prd_reference' => 'Referencia',
                            'prd_description' => 'Descripción',
                        );
                        $headers  = array_merge($headers, $listBranch);
                        $tempArray = array_diff($dataFile[0], $headers);
                        if(count($tempArray)>0){
                            $msg = 'Columnas incorrectas ("'
                                    . implode('","', $tempArray).'")';
                            $strError .= $msg;
                            $error = true;
                        }else{
                            
                            array_shift($dataFile);
                            foreach ($dataFile as $data) {                          
                                //Validamos la referencia ----------------------
                                $data[0] = trim((int) $data[0]);
                                $data[2] = trim($data[2]);
                                if (!isset($data[0])) {
                                    $msg = 'El campo no esta definido';
                                    $strError .= $helpLoadFile->makeMsg(
                                            $countFila, 'Referencia', $msg);
                                    $error = true;
                                } elseif (!is_numeric($data[0])) {
                                    $msg = 'El valor "'
                                            . $data[0]
                                            . '" no es numérico';
                                    $strError .= $helpLoadFile->makeMsg(
                                            $countFila, 'Referencia', $msg);
                                    $error = true;
                                } elseif (!array_key_exists($data[0], $listRef)) {
                                    $msg = 'La referencia "' . $data[0]
                                            . '" no es '
                                            . ' permitida ';
                                    $strError .= $helpLoadFile->makeMsg(
                                            $countFila, 'Referencia', $msg);
                                    $error = true;
                                }
                                //Validamos la descripcion----------------------
                                if (!isset($data[1]) || empty($data[1])) {
                                    $msg = 'El campo no esta definido';
                                    $strError .= $helpLoadFile->makeMsg(
                                            $countFila, 'Descripción', $msg);
                                    $error = true;
                                }
                                //Validamos la cantidad ------------------------  
                                $tempAmount = array();
                                for ($i = 2; $i<= (count($arrayHeader)-1); $i++){
                                    $stringColumn = PHPExcel_Cell::stringFromColumnIndex($i);
                                    if (preg_match('/[A-Za-z]/', $data[$i])) {
                                        $msg = 'Columna ('.$stringColumn.'), Valor "'
                                                . $data[$i]
                                                . '" debe ser numérico mayor a cero(0)';
                                        $strError .= $helpLoadFile->makeMsg(
                                                $countFila, $arrayHeader[$i], $msg);
                                        $error = true;
                                    } elseif (is_numeric($data[$i]) && strlen($data[$i]) > 9) {
                                        $msg = 'Columna ('.$stringColumn.'), Valor "'
                                                . $data[$i]
                                                . '" es muy grande';
                                        $strError .= $helpLoadFile->makeMsg(
                                                $countFila, $arrayHeader[$i], $msg);
                                        $error = true;
                                    }
                                    
                                    if (isset($data[0]) 
                                            && array_key_exists($data[0], $listRef) 
                                            && isset($data[1]) && isset($data[$i]) 
                                            && is_numeric($data[$i]) && $data[$i] >= 1) {
                                        
                                        if(!in_array($data[0], $listProducBran[$arrayHeader[$i]])){
                                            
                                            $tempAmount[$arrayHeader[$i]] = 0;
                                        }else{
                                            $tempAmount[$arrayHeader[$i]] = $data[$i];
                                        }                                        
                                    }
                                }

                                if(count($tempAmount)>0){
                                    $dataProduct = $dataBranchs[$data[0]];
                                    $tempData = array(
                                        'prd_reference' => $dataProduct['prd_reference'],
                                        'prd_description' => $dataProduct['prd_description'],
                                        'prd_category_id' => $dataProduct['prd_category_id'],
                                        'prd_und_exist' => $dataProduct['prd_und_exist'],
                                        'prd_nameCategory' => $dataProduct['prd_nameCategory'],
                                    );
                                    $mergeProduct  = array_merge($tempData, $tempAmount);
                                    $listProduct[$data[0]] = $mergeProduct;
                                }
                                
                                $countFila++;
                            }
                            if(count($listProduct)== 0){
                                $msg = 'Ingrese cantidades para cada item';
                                $strError .= $msg;
                                $error = true;
                            }
                        }
                    }
                } catch (Exception $exc) {
                    $error = true;
                    $strError .= $exc->getMessage();
                    //----------------------------------------------------------
                    Yii::log(__FILE__ . ':' . __LINE__ . ':' . __FUNCTION__
                            . ':' . ' { ' . $exc->getMessage() . '}', CLogger::LEVEL_ERROR, 'b2b.file');
                    //----------------------------------------------------------
                }
            }
            //Respuesta --------------------------------------------------------
            if ($error) {
                echo json_encode(
                        array(
                            'error' => 'Error al cargar el archivo',
                            'msgError' => $strError));
            } else {
                $html = $this->renderPartial('_formProdLoadFileMultiBranch', array(
                    'listProduct' => $listProduct,
                    'arrayHeader' => $arrayHeader,
                    'listBranch' => $listBranch,
                        ), true, false);
                echo json_encode(array('success' => 'true', 'html' => $html));
            }
            Yii::app()->end();

            $model->attributes = $_POST['Order'];
            if ($model->save()) {
                $this->redirect(array('view', 'id' => $model->ord_id));
            }
        }

        $this->render('loadfilemultibranch', array(
            'model' => $model,
            'listBranch' => $listBranch,
            'listClient' => $listClient,
            'defaultBranch' => $defaultBranch,
            'defaultClient' => $defaultClient,
        ));
    }

    /**
     * Metodo para la almacenar pedidos 
     * mediante la carga de archivos
     */
    public function actionLoadfileSales() {
        $this->layout = '//layouts/column1';
        $model = new Order;
        $client = new Client;
        $defaultBranch = '';
        $defaultClient = '';
        $helpLoadFile = new HelperFile;

        $idUser = User::getId();
        $listClient = $client->getListClientSave($idUser);
        if (count($listClient) > 0) {
            $defaultClient = key($listClient);
        }

        $listBranch = $client->getListBranch($defaultClient);
        if (count($listBranch) > 0) {
            if (empty($defaultBranch)) {
                $defaultBranch = key($listBranch);
            }
        }

        if (isset($_GET['ajax']) && $_GET['ajax'] === 'download') {
            $nit = Yii::app()->purifier->purify($_GET['nit']);
            $codeBranch = Yii::app()->purifier->purify($_GET['codeBranch']);
            $listProductDB = ClientSiesa::getListProduct($nit, $codeBranch);
            if (count($listProductDB) > 0) {
                $headers = array(
                    'prd_reference' => 'Referencia',
                    'prd_description' => 'Descripción',
                    'prd_amount' => 'Cantidad',
                    'prd_unit_price' => 'Precio',
                    'prd_und_exist' => 'C. Disponible'
                );
                $nameFile = 'Catálogo-' . $nit . '-' . $codeBranch;
                $arrayItems = array();
                foreach ($listProductDB as $key => $item) {
                    $arrayItems[] = array(
                        'prd_reference' => $item['prd_reference'],
                        'prd_description' => $item['prd_description'],
                        'prd_amount' => ' ',
                        'prd_unit_price' => $item['prd_unit_price'],
                        'prd_und_exist' => $item['prd_und_exist'],
                    );
                }

                if (isset($_GET['type']) && $_GET['type'] === 'excel') {
                    $helpLoadFile->downFileExcel($nameFile, $headers, $arrayItems);
                } elseif (isset($_GET['type']) && $_GET['type'] === 'text') {
                    $helpLoadFile->downFileText($nameFile, $headers, $arrayItems);
                }
            }
            return false;
            Yii::app()->end();
        }


        if (isset($_GET['Order']['uploadFile'])) {

            $nit = Yii::app()->purifier->purify($_GET['nit']);
            $codeBranch = Yii::app()->purifier->purify($_GET['codeBranch']);
            $error = false;
            $strError = '';
            $contFile = array();
            $dataFile = array();

            $listProductDB = ClientSiesa::getListProduct($nit, $codeBranch);
            $listRef = array();
            if (count($listProductDB) > 0) {
                foreach ($listProductDB as $key => $value) {
                    $listRef[$value['prd_reference']] = $key;
                }
            } else {
                echo array(
            'error' => 'Error al cargar el archivo',
            'msgError' => 'No se encontraron productos relacionados');
                Yii::app()->end();
            }

            $fileData = CUploadedFile::getInstance($model, 'uploadFile');
            $fileType = $fileData->getType();
            $fileName = $fileData->getTempName();

            if ($fileType === 'text/plain' || $fileType === 'application/vnd.ms-excel}' || $fileType === 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet') {
                try {
                    if ($fileType === 'text/plain') {
                        $file = fopen($fileName, 'r');
                        if ($file) {
                            while (!feof($file)) {
                                $line = fgets($file);
                                if (!empty($line))
                                    $contFile[] = utf8_encode($line);
                            }
                            fclose($file);
                        } else {
                            $strError .= 'Error al cargar el archivo "'
                                    . $fileName . '"';
                            $error = true;
                        }
                        if (count($contFile) > 0) {
                            foreach ($contFile as $value) {
                                $dataFile[] = explode(';', $value);
                            }
                        }
                    } else {
                        $dataFile = Yii::app()->yexcel->readActiveSheet(
                                $fileName, false);
                    }

                    $countFila = 2;
                    $listProduct = array();
                    if (count($dataFile) > 0) {
                        array_shift($dataFile);
                        foreach ($dataFile as $data) {
                            //Valido que las filas tengan 3 campo (Ref, Desc, Cant)-
                            if (count($data) != 5 && !empty($data)) {
                                $strError .= '<strong>Fila: </strong> '
                                        . $countFila
                                        . ' <strong>Msg: </strong> La fila no '
                                        . 'tiene la extructura esperada <br/>';
                                $error = true;
                            } else {
                                //Validamos la referencia ----------------------
                                //$data[0] = trim((int) $data[0]);
                                $data[0] = trim($data[0]);
                                $data[2] = trim($data[2]);
                                if (!isset($data[0])) {
                                    $msg = 'El campo no esta definido';
                                    $strError .= $helpLoadFile->makeMsg(
                                            $countFila, 'Referencia', $msg);
                                    $error = true;
                                }
                                /* elseif(!is_numeric($data[0])) {
                                  $msg = 'El valor "'
                                  . $data[0]
                                  . '" no es numérico';
                                  $strError .= $helpLoadFile->makeMsg(
                                  $countFila, 'Referencia', $msg);
                                  $error = true;
                                  } */
                                //elseif(!array_key_exists($data[0], $listRef)) {
                                elseif (!isset($listRef[$data[0]])) {
                                    $msg = 'La referencia "' . $data[0]
                                            . '" no es '
                                            . ' permitida ';
                                    $strError .= $helpLoadFile->makeMsg(
                                            $countFila, 'Referencia', $msg);
                                    $error = true;
                                }
                                //Validamos la descripcion----------------------
                                if (!isset($data[1]) || empty($data[1])) {
                                    $msg = 'El campo no esta definido';
                                    $strError .= $helpLoadFile->makeMsg(
                                            $countFila, 'Descripción', $msg);
                                    $error = true;
                                }
                                //Validamos la cantidad ------------------------                                                     
                                if (!isset($data[2])) {
                                    $msg = 'El campo no esta definido';
                                    $strError .= $helpLoadFile->makeMsg(
                                            $countFila, 'Cantidad', $msg);
                                    $error = true;
                                } elseif (preg_match('/[A-Za-z]/', $data[2])) {
                                    $msg = 'El valor "'
                                            . $data[2]
                                            . '" debe ser numérico mayor a cero(0)';
                                    $strError .= $helpLoadFile->makeMsg(
                                            $countFila, 'Cantidad', $msg);
                                    $error = true;
                                } elseif (is_numeric($data[2]) && strlen($data[2]) > 9) {
                                    $msg = 'El valor "'
                                            . $data[2]
                                            . '" es muy grande';
                                    $strError .= $helpLoadFile->makeMsg(
                                            $countFila, 'Cantidad', $msg);
                                    $error = true;
                                }

                                //Validamos la cantidad ------------------------                                                     
                                if (!isset($data[3])) {
                                    $msg = 'El campo no esta definido';
                                    $strError .= $helpLoadFile->makeMsg(
                                            $countFila, 'Precio', $msg);
                                    $error = true;
                                } elseif (preg_match('/[A-Za-z]/', $data[3])) {
                                    $msg = 'El valor "'
                                            . $data[3]
                                            . '" debe ser numérico mayor a cero(0)';
                                    $strError .= $helpLoadFile->makeMsg(
                                            $countFila, 'Precio', $msg);
                                    $error = true;
                                } elseif (is_numeric($data[3]) && strlen($data[3]) > 9) {
                                    $msg = 'El valor "'
                                            . $data[3]
                                            . '" es muy grande';
                                    $strError .= $helpLoadFile->makeMsg(
                                            $countFila, 'Precio', $msg);
                                    $error = true;
                                }

                                if (isset($data[0]) && array_key_exists($data[0], $listRef) && isset($data[1]) && isset($data[2]) && is_numeric($data[2]) && $data[2] >= 1 && is_numeric($data[3])) {
                                    $dataId = $listRef[$data[0]];
                                    $dataProduct = $listProductDB[$dataId];
                                    $dataProduct['prd_amount'] = $data[2];
                                    $dataProduct['prd_unit_price'] = $data[3];
                                    $listProduct[$data[0]] = $dataProduct;
                                }
                            }
                            $countFila++;
                        }
                    }
                } catch (Exception $exc) {
                    $error = true;
                    //----------------------------------------------------------
                    Yii::log(__FILE__ . ':' . __LINE__ . ':' . __FUNCTION__
                            . ':' . ' { ' . $exc->getMessage() . '}', CLogger::LEVEL_ERROR, 'b2b.file');
                    //----------------------------------------------------------
                }
            }
            //Respuesta --------------------------------------------------------
            if ($error) {
                echo json_encode(
                        array(
                            'error' => 'Error al cargar el archivo',
                            'msgError' => $strError));
            } else {
                $html = $this->renderPartial('_formProductsLoadFileSales', array(
                    'listProduct' => $listProduct
                        ), true, false);
                echo json_encode(array('success' => 'true', 'html' => $html));
            }
            Yii::app()->end();

            $model->attributes = $_POST['Order'];
            if ($model->save()) {
                $this->redirect(array('view', 'id' => $model->ord_id));
            }
        }

        $this->render('loadfileSales', array(
            'model' => $model,
            'listBranch' => $listBranch,
            'listClient' => $listClient,
            'defaultBranch' => $defaultBranch,
            'defaultClient' => $defaultClient,
        ));
    }

    /**
     * Metodo para cambiar el estado de la petidion
     * 
     * Este metodo recibe el parametro 'status' por metodo GET
     * y cambia el estado 
     * 
     * @param int $id Id de la peticion
     */
    public function actionChangestatus($id) {
        if (isset($_GET['status'])) {
            $model = $this->loadModel($id);
            //Cambio de estado ------------------------------------------------
            if ($_GET['status'] === Order::STATUS_PENDING) {
                $model->ord_status = Order::STATUS_PENDING;
                $this->_sendMail($model, $model::STATUS_PENDING);
            }

            if ($_GET['status'] === Order::STATUS_ALLOW) {
                $model->ord_status = Order::STATUS_ALLOW;
                $model->ord_user_allow = Yii::app()->user->name;
                $this->_sendMail($model);
            }
            $model->save();
        }
        $url = Yii::app()->createUrl("/order/admin");
        $this->redirect($url);
    }

    /**
     * Metodo para presentar la liquidacion de los 
     * pedidos
     */
    public function actionLiquidate($id) {
        $this->layout = '//layouts/column1';
        $model = $this->loadModel($id);
        $client = new Client;
        $nameClient = $client->getNameClient($model->ord_nit);
        $nameBranch = $client->getNameBranch($model->ord_nit, $model->ord_codeBranch);

        if ($model->ord_status === Order::STATUS_ALLOW) {
            $url = Yii::app()->createUrl("/order/admin");
            $this->redirect($url);
        }

//Valida si se tiene acceso a la liquidacion del pedido-----------------
        if (!$model->validateLiquidateOrder($id)) {
            $url = Yii::app()->createUrl("/order/admin");
            $this->redirect($url);
        }

// Uncomment the following line if AJAX validation is needed
// $this->performAjaxValidation($model);

        if (isset($_POST['Order'])) {
            $url = Yii::app()->createUrl("/order/admin");
            $this->redirect($url);
        }

        $this->render('liquidate', array(
            'model' => $model,
            'nameBranch' => $nameBranch,
            'nameClient' => $nameClient,
        ));                
    }

    /**
     * Metodo para obetener el listado de 
     * las sucursales segun el cliente
     */
    public function actionGetbranch() {
        $this->layout = '//layouts/column3';
        if (isset($_POST['nit'])) {
            $defaultBranch = '';
            $nit = Yii::app()->purifier->purify($_POST['nit']);
            $client = new Client;
            $listBranch = $client->getListBranch($nit);

            if (isset($_POST['load']) && $_POST['load'] === 'load') {
                $this->render('_selectBranchLoad', array(
                    'listBranch' => $listBranch,
                ));
            } else {
                $this->render('_selectBranch', array(
                    'listBranch' => $listBranch,
                ));
            }
        }
    }

    /**
     * Updates a particular model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id the ID of the model to be updated
     */
    public function actionUpdate($id) {
        $model = $this->loadModel($id);
// Uncomment the following line if AJAX validation is needed
// $this->performAjaxValidation($model);
        if (isset($_POST['Order'])) {
            $model->attributes = $_POST['Order'];
            if ($model->save()) {
                $this->redirect(array('view', 'id' => $model->ord_id));
            }
        }

        $this->render('update', array(
            'model' => $model,
        ));
    }

    /**
     * Deletes a particular model.
     * If deletion is successful, the browser will be redirected to the 'admin' page.
     * @param integer $id the ID of the model to be deleted
     */
    public function actionDelete($id) {
        if (Yii::app()->request->isPostRequest) {
// we only allow deletion via POST request
            $model = $this->loadModel($id);
            if ($model->ord_status !== Order::STATUS_PARCIAL) {
                $this->_sendMail($model, $model::STATUS_DELETE);
            }

            $model->delete();
// if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
            if (!isset($_GET['ajax'])) {
                $this->redirect(
                        isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array(
                            'admin'));
            }
        } else {
            throw new CHttpException(400, 'Invalid request. Please do not repeat this request again.');
        }
    }

    /**
     * Lists all models.
     */
    public function actionIndex() {
        $dataProvider = new CActiveDataProvider('Order');
        $this->render('index', array(
            'dataProvider' => $dataProvider,
        ));
    }

    /**
     * Manages all models.
     */
    public function actionAdmin() {
        $model = new Order('search');
        $client = new Client;
        $model->unsetAttributes();  // clear any default values
        if (isset($_GET['Order'])) {
            $model->attributes = $_GET['Order'];
        }

        $this->render('admin', array(
            'model' => $model,
            'client' => $client,
        ));
    }

    /**
     * Returns the data model based on the primary key given in the GET variable.
     * If the data model is not found, an HTTP exception will be raised.
     * @param integer $id the ID of the model to be loaded
     * @return Order the loaded model
     * @throws CHttpException
     */
    public function loadModel($id) {
        $model = Order::model()->findByPk($id);
        if ($model === null) {
            throw new CHttpException(404, 'The requested page does not exist.');
        }
        return $model;
    }

    /**
     * Performs the AJAX validation.
     * @param Order $model the model to be validated
     */
    protected function performAjaxValidation($model) {
        if (isset($_POST['ajax']) && $_POST['ajax'] === 'order-form') {
            echo CActiveForm::validate($model);
            Yii::app()->end();
        }
    }

    /**
     * Metodo para enviar las compras al ERP Siesa
     * 
     * @param type $model
     * @param type $assignPrice
     * 
     * @author Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2013 INGENEO S.A.S.
     * @license http://www.opensource.org/licenses/bsd-license.php  BSD License
     * @version Release: $Id$
     */
    public function _saveOrderSiesa($model, $assignPrice = false) {        
        if (!empty($model) && is_object($model)) {
            //Consumo de servicio Siesa-----------------------------------------
            try {
                $wsSiesa = new WsSiesa();                
                if (!$wsSiesa->sendOrderSiesa($model, $assignPrice)) {
                    $model->ord_status = Order::STATUS_PENDING;
                    $model->save();
                    Yii::app()->user->setFlash(
                            "error", 'Error al Autorizar el pedido No. '
                            . $model->ord_id
                            . ', por favor inténtelo mas tarde');
                } else {
                    Yii::app()->user->setFlash(
                            "success", 'La transacción No. '
                            . $model->ord_id
                            . ' se envió con éxito');
                    //Envio de correo a los pedidos aprobados ------------------
                    $this->_sendMail($model);
                    //----------------------------------------------------------
                }
            } catch (Exception $exc) {
                Yii::log(__FILE__ . ':' . __LINE__ . ':'
                        . __FUNCTION__ . ':'
                        . ' {' . $exc->getMessage() . '}', CLogger::LEVEL_ERROR, 'b2b.ws');
            }
        }
    }

    /**
     * Metodo para enviar el correo con la informacion 
     * del pedido
     * 
     * @param Order $model
     * @author Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2013 INGENEO S.A.S.
     * @license http://www.opensource.org/licenses/bsd-license.php  BSD License
     * @version SVN: $Id$
     */
    private function _sendMail($model, $type = null) {
        $client = new Client;
        // Informacion del cliente y la sucursal -------------------------------
        $nameClient = $client->getNameClient($model->ord_nit);
        $nameBranch = $client->getNameBranch($model->ord_nit, $model->ord_codeBranch);
        //Listado de productos -------------------------------------------------
        $orderProduct = new OrderProduct;
        $listProduct = $orderProduct->getProducts($model->ord_id);
        // Asignacion de admin para JDH ----------------------------------------
        $arrayEmail[] = Yii::app()->params['adminEmail'];
        // Asignacion de asesor para JDH ---------------------------------------
        $arrayEmail[] = Yii::app()->params['asesorEmail'];
        //Seleccion  de la plantilla segun le tipo -----------------------------
        switch ($type) {
            case Order::STATUS_PENDING:
                $arrayEmail = array();
                $subject = 'JDH - B2B - Solicitud APROBACIÓN';
                $message = $this->renderPartial('templateMail', array(
                    'model' => $model,
                    'nameBranch' => $nameBranch,
                    'nameClient' => $nameClient,
                    'listProduct' => $listProduct,
                        ), true, false);
                break;
            case Order::STATUS_DELETE:
                $subject = 'JDH - B2B - Pedido ELIMINADO';
                $message = $this->renderPartial('templateMailDelete', array(
                    'model' => $model,
                    'nameBranch' => $nameBranch,
                    'nameClient' => $nameClient,
                    'listProduct' => $listProduct,
                        ), true, false);
                break;
            default:
                $subject = 'JDH - B2B - Informacion pedido APROBADO';
                $message = $this->renderPartial('templateMail', array(
                    'model' => $model,
                    'nameBranch' => $nameBranch,
                    'nameClient' => $nameClient,
                    'listProduct' => $listProduct,
                        ), true, false);
                break;
        }
        //Usuario creador del pedido
        $arrayEmail[] = User::getUserMail($model->ord_user);
        //usuario que aprueba el pedido
        $arrayEmail[] = User::getUserMail($model->ord_user_allow);
        $mail = new Mail();
        try {
            $mail->sendMail($arrayEmail, $message, $subject);
        } catch (Exception $exc) {
            Yii::log(__FILE__ . ':' . __LINE__ . ':' . __FUNCTION__
                    . ':' . ' {_sendMail ERROR ['
                    . $exc->getMessage() . ']}', CLogger::LEVEL_ERROR, 'b2b.mail');
        }        
    }
    
    /**
     * Metodo para enviar el correo con la informacion 
     * del pedido
     * 
     * @param Order $model
     * 
     * @author Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2017 INGENEO S.A.S.
     * @license http://www.opensource.org/licenses/bsd-license.php  BSD License
     * @version SVN: $Id$
     */
    public static function sendMailVendedor($model) {
        $client = new Client;
        // Informacion del cliente y la sucursal -------------------------------
        $nameClient = $client->getNameClient($model->ord_nit);
        $nameBranch = $client->getNameBranch($model->ord_nit, $model->ord_codeBranch);
        //Listado de productos -------------------------------------------------
        $orderProduct = new OrderProduct;
        $listProduct = $orderProduct->getProducts($model->ord_id);        
        //Verificamos si hay inventario en 0 -----------------------------------
        $notifVendedor = false;
        foreach ($listProduct as $product) {
            //si la cantidad es mayor al inventario notificamos al venedor                            
            if($product['orp_und_exist'] != '' && is_numeric($product['orp_und_exist'])){                                                            
                if($product['orp_amount'] > $product['orp_und_exist']){                                    
                    $notifVendedor = true;
                }
            }else{
                $notifVendedor = true;
            }
        }  
        if($notifVendedor){
            //Traemos la info del vendedor -----------------------------------------
            $infoVendedor = ClientSiesa::getInfoVendedor($model->ord_nit, $model->ord_codeBranch);
            if(count($infoVendedor)>0){
                $arrayEmail[] = $infoVendedor[0]['email'];
                $arrayEmail[] = 'arcila.alexander@gmail.com';
                Yii::log(__FILE__ . ':' . __LINE__ . ':' . __FUNCTION__
                        . ':' . ' {_emails ['
                        . print_r($arrayEmail, true) . ']}', CLogger::LEVEL_ERROR, 'b2b.mail');
            }          

            $subject = 'JDH - B2B - Pedido con Faltantes';
            $message = $this->renderPartial('templateMailPendient', array(
                'model' => $model,
                'nameBranch' => $nameBranch,
                'nameClient' => $nameClient,
                'listProduct' => $listProduct,
                    ), true, false);                        
            $mail = new Mail();
            try {
                $mail->sendMail($arrayEmail, $message, $subject);
            } catch (Exception $exc) {            
                Yii::log(__FILE__ . ':' . __LINE__ . ':' . __FUNCTION__
                        . ':' . ' {_sendMail ERROR ['
                        . $exc->getMessage() . ']}', CLogger::LEVEL_ERROR, 'b2b.mail');
            }        
        }        
    }

}
