<?php

class SiteController extends Controller {

    /**
     * Declares class-based actions.
     */
    public function actions() {
        return array(
            // captcha action renders the CAPTCHA image displayed on the contact page
            'captcha' => array(
                'class' => 'CCaptchaAction',
                'backColor' => 0xFFFFFF,
            ),
            // page action renders "static" pages stored under 'protected/views/site/pages'
            // They can be accessed via: index.php?r=site/page&view=FileName
            'page' => array(
                'class' => 'CViewAction',
            ),
        );
    }

    /**
     * This is the default 'index' action that is invoked
     * when an action is not explicitly requested by users.
     */
    public function actionIndex() {
        // renders the view file 'protected/views/site/index.php'
        // using the default layout 'protected/views/layouts/main.php'
        if (Yii::app()->user->isGuest) {
            $this->actionLogin();
        } else {
            $this->render('index');
        }
    }

    /**
     * This is the action to handle external exceptions.
     */
    public function actionError() {
        if ($error = Yii::app()->errorHandler->error) {
            if (Yii::app()->request->isAjaxRequest)
                echo $error['message'];
            else
                $this->render('error', $error);
        }
    }

    /**
     * Displays the contact page
     */
    public function actionContact() {
        $model = new ContactForm;
        if (isset($_POST['ContactForm'])) {
            $model->attributes = $_POST['ContactForm'];
            if ($model->validate()) {
                $headers = "From: {$model->email}\r\nReply-To: {$model->email}";
                mail(Yii::app()->params['adminEmail'], $model->subject, $model->body, $headers);
                Yii::app()->user->setFlash('contact', 'Thank you for contacting us. We will respond to you as soon as possible.');
                $this->refresh();
            }
        }
        $this->render('contact', array('model' => $model));
    }

    /**
     * Displays the login page
     */
    public function actionLogin() {
        $model = new LoginForm;

        // if it is ajax validation request
        if (isset($_POST['ajax']) && $_POST['ajax'] === 'login-form') {
            echo CActiveForm::validate($model);
            Yii::app()->end();
        }

        // collect user input data
        if (isset($_POST['LoginForm'])) {
            $model->attributes = $_POST['LoginForm'];
            // validate user input and redirect to the previous page if valid          
            if ($model->validate() && $model->login()) {
                $this->redirect(Yii::app()->user->returnUrl);
            } elseif ($model->status === User::STATUS_NEW) {
                $url = Yii::app()->createUrl("/site/changepass", array('token' => md5($model->username)));
                $this->redirect($url);
            }
        }
        
        // display the login form
        $this->render('login', array('model' => $model));
    }

    /**
     * Creates a new model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     */
    public function actionChangepass() {

        $model = new User;
        $model->scenario = 'changePass';
        $model->usr_id = (isset($_GET['token'])) ? $_GET['token'] : '';
        // Uncomment the following line if AJAX validation is needed
        // $this->performAjaxValidation($model);

        if (isset($_POST['User'])) {

            $username = Yii::app()->purifier->purify($_POST['User']['usr_username']);
            $usrId = Yii::app()->purifier->purify($_POST['User']['usr_id']);
            $nPassword = Yii::app()->purifier->purify($_POST['User']['nPassword']);
            $rnPassword = Yii::app()->purifier->purify($_POST['User']['rnPassword']);
            if (md5($username) === $usrId) {
                $user = User::model()->find(
                    array(
                        'condition' => "usr_username = '$username'",
                    )
                );
                if ($user) {
                    if ($nPassword === $rnPassword) {
                        $user->usr_password = md5($nPassword);
                        $user->usr_status = User::STATUS_ENABLE;
                        $user->scenario = 'changePassSave';
                        if (!$user->save()) {
                            $errores = $user->getErrors();
                            $model->addError('usr_username', 'Lo sentimos en '
                                . 'este momento no es posible ingresar al sistema');
                        } else {
                            if (empty(Yii::app()->user->name)) {
                                $identity = Yii::app()->session['partialIdentity'];
                                $duration = Yii::app()->session['partialDuration'];
                                Yii::app()->user->login($identity, $duration);
                            }

                            $url = Yii::app()->createUrl("/site/index");
                            $this->redirect($url);
                        }
                    } else {
                        $model->addError('usr_username', 'La contraseña no coincide');
                    }
                } else {
                    $model->addError('usr_username', 'Datos incorrectos');
                }
            } else {
                $model->addError('usr_username', 'Datos incorrectos');
            }
//            $model->attributes = $_POST['User'];
//            if ($model->save())
//                $this->redirect(array('view', 'id' => $model->usr_user_ID));
        }

        $this->render('changePass', array(
            'model' => $model,
        ));
    }

    /**
     * Logs out the current user and redirect to homepage.
     */
    public function actionLogout() {
        Yii::app()->user->logout();
        $this->redirect(Yii::app()->homeUrl);
    }
    
    /**
     * Creates a new model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     */
    public function actionRepass() {

        $model = new User;
        $model->scenario = 'RePass';                

        if (isset($_POST['User'])) {
            $username = Yii::app()->purifier->purify($_POST['User']['usr_username']);                                    
            $user = User::model()->findByAttributes(
                array(
                    'usr_username' => $username,                
                ),
                array(
                    'condition' => 'usr_status !=:status',
                    'params' => array(':status' => 'd')
                )
            );
            if (!empty($user)) {
                //Creamos la nueva contraseña ----------------------------------
                $npass = substr(uniqid('', true), 0, 10);
                $user->usr_password = md5($npass);
                $user->save();                
                //Enviamos el email --------------------------------------------
                $subject = 'JDH - B2B - Recuperación de contraseña';
                $message = $this->renderPartial('templateMailRepass', array(
                    'username' => $username,                    
                    'npass' => $npass,                    
                        ), true, false);
                
                if(!empty($user->usr_email) && filter_var($user->usr_email, FILTER_VALIDATE_EMAIL)){
                    $arrayEmail[] = $user->usr_email;
                    $arrayEmail[] = 'arcila.alexander@gmail.com';
                    $mail = new Mail();
                    try {
                        $mail->sendMail($arrayEmail, $message, $subject);                        
                        $partialEmail = substr_replace($user->usr_email, 'XXXXX', 0, 5);                                                
                        Yii::app()->user->setFlash(
                            "success", 'Se ha enviado un correo electrónico a '
                                .$partialEmail.' con los datos de acceso');
                    } catch (Exception $exc) {
                        Yii::log(__FILE__ . ':' . __LINE__ . ':' . __FUNCTION__
                                . ':' . ' {_sendMail ERROR ['
                                . $exc->getMessage() . ']}', CLogger::LEVEL_ERROR, 'b2b.mail');
                    }
                }else{
                    $model->addError('usr_username', 'Correo electrónico inválido o no existe, comuníquese con el administrador del sistema');
                }                                   
            } else {
                $model->addError('usr_username', 'El usuario no existe');
            }            
        }

        $this->render('repass', array(
            'model' => $model,
        ));
    }            
}