<?php

class UserController extends Controller
{

    /**
     * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
     * using two-column layout. See 'protected/views/layouts/column2.php'.
     */
    public $layout = '//layouts/column2';

    /**
     * @return array action filters
     */
    public function filters()
    {
        return array(
            'accessControl', // perform access control for CRUD operations
            'postOnly + delete', // we only allow deletion via POST request
        );
    }

    /**
     * Specifies the access control rules.
     * This method is used by the 'accessControl' filter.
     * @return array access control rules
     */
    public function accessRules()
    {
        return array(
            array('allow', // allow authenticated users to access all actions
                'users' => array('@'),
            ),
            array('deny'),
        );
    }

    /**
     * Displays a particular model.
     * @param integer $id the ID of the model to be displayed
     */
    public function actionView($id)
    {
        $this->render('view',
            array(
            'model' => $this->loadModel($id),
        ));
    }

    /**
     * Creates a new model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     */
    public function actionCreate()
    {
        $model = new User;
        $client = new Client;
        $clientSiesa = new ClientSiesa();
        // Uncomment the following line if AJAX validation is needed
        // $this->performAjaxValidation($model);

        if(isset($_POST['User'])) {

            $model->attributes = Yii::app()->purifier->purify($_POST['User']);
            $model->usr_status = User::STATUS_NEW;            
            if($model->validate()) {
                $model->usr_password = md5($model->usr_password);
                if($model->save()) {
                    $this->redirect(array('view', 'id' => $model->usr_user_ID));
                }
            }
        }

        $model->usr_password = '';

        $this->render('create',
            array(
            'model' => $model,
            'client' => $client,
            'clientSiesa' => $clientSiesa,
        ));
    }

    /**
     * Updates a particular model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id the ID of the model to be updated
     */
    public function actionUpdate($id)
    {
        $model = $this->loadModel($id);
        $client = new Client;
        $clientSiesa = new ClientSiesa();
        $beforePassword = $model->usr_password;
        $model->usr_password = '';
        $model->scenario = 'updateForm';
        
        if(isset($_GET['Client'])) {
            $client->attributes = Yii::app()->purifier->purify($_GET['Client']);
        }

        // Uncomment the following line if AJAX validation is needed
        // $this->performAjaxValidation($model);

        if(isset($_POST['User'])) {
            $model->attributes = Yii::app()->purifier->purify($_POST['User']);
            $password = Yii::app()->purifier->purify($_POST['User']['usr_password']);
            $password = trim($password);
            if(empty($password)){                
                $model->usr_password = $beforePassword;
            }else{
                $model->usr_password = md5($password);
            }
                        
            if($model->save()) {
                $this->redirect(array('view', 'id' => $model->usr_user_ID));
            }
        }

        $this->render('update',
            array(
            'model' => $model,
            'client' => $client,
            'clientSiesa' => $clientSiesa,
        ));
    }

    /**
     * Deletes a particular model.
     * If deletion is successful, the browser will be redirected to the 'admin' page.
     * @param integer $id the ID of the model to be deleted
     */
    public function actionDelete($id)
    {
        $this->loadModel($id)->delete();

        // if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
        if(!isset($_GET['ajax']))
                $this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array(
                    'admin'));
    }

    /**
     * Lists all models.
     */
    public function actionIndex()
    {
        $dataProvider = new CActiveDataProvider('User');
        $this->render('index',
            array(
            'dataProvider' => $dataProvider,
        ));
    }

    /**
     * Manages all models.
     */
    public function actionAdmin()
    {
        $model = new User('search');
        $client = new Client;
        $clientSiesa = new ClientSiesa();
        $model->unsetAttributes();  // clear any default values
        if(isset($_GET['User'])){
            $model->attributes = $_GET['User'];
        }
        
        if(isset($_GET['Client'])){
            $client->attributes = $_GET['Client'];
        }


        $this->render('admin', array(
            'model' => $model,
            'client' => $client,
            'clientSiesa' => $clientSiesa,
        ));
    }

    /**
     * Metodo para obtener el listado de sedes segun el nit daddi
     */
    public function actionGetlistbranch()
    {
        $arrayBranch = array();
        if(isset($_POST['listNit'])) {
            $clientSiesa = new ClientSiesa();
            $client = new Client;
            $nit = Yii::app()->purifier->purify($_POST['listNit']);
            $idUser = Yii::app()->purifier->purify($_POST['idUser']);
            if(!empty($nit) && !empty($idUser)) {
                $arrayBranch = $clientSiesa->getListBranch($nit, $idUser);
            }
        }
        $this->renderPartial('_selectBranch',
            array(
            'client' => $client,
            'arrayBranch' => $arrayBranch,
            ), false, true);
    }
    
    /**
     * Metodo para obtener el listado de sedes segun el nit daddi
     */
    public function actionGetlistbranchsearch()
    {
        $arrayBranch = array();
        if(isset($_POST['listNit'])) {
            $clientSiesa = new ClientSiesa();
            $client = new Client;
            $nit = Yii::app()->purifier->purify($_POST['listNit']);
            if(!empty($nit)) {
                $arrayBranch = $clientSiesa->getListBranchSearch($nit);
            }
        }
        $this->renderPartial('_selectBranch',
            array(
            'client' => $client,
            'arrayBranch' => $arrayBranch,
            ), false, true);
    } 
    
    /**
     * Performs the AJAX validation.
     * @param User $model the model to be validated
     */
    public function actionActiveusers()
    {
        if(isset($_POST['selected']) && is_array($_POST['selected'])) {
            User::model()->updateAll(array('usr_status'=>'e'),
                    "usr_user_ID IN('".implode("','", $_POST['selected'])."')");
            Yii::app()->end();
        }
    }
    
    /**
     * Performs the AJAX validation.
     * @param User $model the model to be validated
     */
    public function actionInactiveusers()
    {
        if(isset($_POST['selected']) && is_array($_POST['selected'])) {
            User::model()->updateAll(array('usr_status'=>'d'),
                    "usr_user_ID IN('".implode("','", $_POST['selected'])."')");
            Yii::app()->end();
        }
    }

    /**
     * Returns the data model based on the primary key given in the GET variable.
     * If the data model is not found, an HTTP exception will be raised.
     * @param integer $id the ID of the model to be loaded
     * @return User the loaded model
     * @throws CHttpException
     */
    public function loadModel($id)
    {
        $model = User::model()->findByPk($id);
        if($model === null)
                throw new CHttpException(404,
            'The requested page does not exist.');
        return $model;
    }

    /**
     * Performs the AJAX validation.
     * @param User $model the model to be validated
     */
    protected function performAjaxValidation($model)
    {
        if(isset($_POST['ajax']) && $_POST['ajax'] === 'user-form') {
            echo CActiveForm::validate($model);
            Yii::app()->end();
        }
    }

}
