<?php

/**
 * This is the model class for table "b2b_bodega_item".
 *
 * The followings are the available columns in table 'b2b_bodega_item':
 * @property integer $bgi_id
 * @property string $bgi_centroOperacion
 * @property string $bgi_nombreCentroOp
 * @property string $bgi_referenciaItem
 * @property string $bgi_descripcionItem
 * @property string $bgi_codigoBodega
 * @property string $bgi_nombreBodega
 */
class BodegaItem extends CActiveRecord
{    
    
	/**
     * @const Codigo de las bodegas por defecto
     */
    const CODE_DEFAULT = 'LYSME';
    
    /**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'b2b_bodega_item';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('bgi_centroOperacion, bgi_referenciaItem, bgi_codigoBodega', 'required'),
			array('bgi_centroOperacion, bgi_referenciaItem, bgi_codigoBodega', 'length', 'max'=>45),
			array('bgi_nombreCentroOp', 'length', 'max'=>150),
			array('bgi_descripcionItem, bgi_nombreBodega', 'length', 'max'=>250),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('bgi_id, bgi_centroOperacion, bgi_nombreCentroOp, bgi_referenciaItem, bgi_descripcionItem, bgi_codigoBodega, bgi_nombreBodega', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'bgi_id' => 'Bgi',
			'bgi_centroOperacion' => 'codigo centro de operacion',
			'bgi_nombreCentroOp' => 'nombre centro de operacion ',
			'bgi_referenciaItem' => 'referencia item',
			'bgi_descripcionItem' => 'descripcion  del item ',
			'bgi_codigoBodega' => 'codigo de la bodega',
			'bgi_nombreBodega' => 'nombre de la bodega',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('bgi_id',$this->bgi_id);
		$criteria->compare('bgi_centroOperacion',$this->bgi_centroOperacion,true);
		$criteria->compare('bgi_nombreCentroOp',$this->bgi_nombreCentroOp,true);
		$criteria->compare('bgi_referenciaItem',$this->bgi_referenciaItem,true);
		$criteria->compare('bgi_descripcionItem',$this->bgi_descripcionItem,true);
		$criteria->compare('bgi_codigoBodega',$this->bgi_codigoBodega,true);
		$criteria->compare('bgi_nombreBodega',$this->bgi_nombreBodega,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return BodegaItem the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
    
    /**
     * Matodo para obtener los identificadores
     * de las bodegas segun el centro de costos 
     * y la referencia
     * 
     * @param int $idCo      Identificador del centro de operacion
     * @param int $reference Referencia del item
     * 
     * @return boolean
     * @author    Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2014 INGENEO S.A.S.
     * @license   http://www.opensource.org/licenses/bsd-license.php  BSD License
     * @version   Release: $Id$
     * @link      http://www.ingeneo.com.co
     */
    public static function getIdBodega($idCo, $reference){
        if(!empty($idCo) && is_numeric($idCo) 
            && !empty($reference) && is_numeric($reference)){
            $criteria=new CDbCriteria;
            $criteria->addCondition('bgi_centroOperacion =' . $idCo,'and');
            $criteria->addCondition('bgi_referenciaItem =' . $reference,'and');
            $result = self::model()->find($criteria);
            if($result){
                return $result->bgi_codigoBodega;
            }else{
                return self::CODE_DEFAULT;
            }
        }
        return false;
    }
}
