<?php

/**
 * This is the model class for table "b2b_centro_factura".
 *
 * The followings are the available columns in table 'b2b_centro_factura':
 * @property integer $cef_id
 * @property integer $cef_nit
 * @property string $cef_nombreCliente
 * @property string $cef_codigoSucursalFact
 * @property string $cef_nombreSucursalFac
 * @property string $cef_codigoSucursalEnv
 * @property string $cef_nombreSucursalEnv
 */
class CentroFactura extends CActiveRecord
{

    /**
     * @return string the associated database table name
     */
    public function tableName()
    {
        return 'b2b_centro_factura';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules()
    {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('cef_nit, cef_codigoSucursalFact, cef_codigoSucursalEnv', 'required'),
            array('cef_nit', 'numerical', 'integerOnly' => true),
            array('cef_nombreCliente, cef_codigoSucursalFact, cef_codigoSucursalEnv',
                'length', 'max' => 45),
            array('cef_nombreSucursalFac, cef_nombreSucursalEnv', 'length', 'max' => 250),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('cef_id, cef_nit, cef_nombreCliente, cef_codigoSucursalFact, cef_nombreSucursalFac, cef_codigoSucursalEnv, cef_nombreSucursalEnv',
                'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations()
    {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels()
    {
        return array(
            'cef_id' => 'Cef',
            'cef_nit' => 'Nit de la compañia',
            'cef_nombreCliente' => 'Nombre de la compañia',
            'cef_codigoSucursalFact' => 'Codigo de la sucursal a facturar',
            'cef_nombreSucursalFac' => 'Nombre de la sucursal a facturar',
            'cef_codigoSucursalEnv' => 'Codigo de la sucursal a enviar',
            'cef_nombreSucursalEnv' => 'Nombre de la sucursal a enviar',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search()
    {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('cef_id', $this->cef_id);
        $criteria->compare('cef_nit', $this->cef_nit);
        $criteria->compare('cef_nombreCliente', $this->cef_nombreCliente, true);
        $criteria->compare('cef_codigoSucursalFact',
            $this->cef_codigoSucursalFact, true);
        $criteria->compare('cef_nombreSucursalFac',
            $this->cef_nombreSucursalFac, true);
        $criteria->compare('cef_codigoSucursalEnv',
            $this->cef_codigoSucursalEnv, true);
        $criteria->compare('cef_nombreSucursalEnv',
            $this->cef_nombreSucursalEnv, true);

        return new CActiveDataProvider($this,
            array(
            'criteria' => $criteria,
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return CentroFactura the static model class
     */
    public static function model($className = __CLASS__)
    {
        return parent::model($className);
    }

    /**
     * Metodo para obtener el centro de facturacion 
     * y envio
     * 
     * @param int    $nit        Nit del cliente 
     * @param string $codeBranch Codigo de la sucursal
     * 
     * @return \stdClass|boolean
     * @author Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2013 INGENEO S.A.S.
     * @license http://www.opensource.org/licenses/bsd-license.php  BSD License
     * @version Release: $Id$
     */
    public static function getCentroFactura($nit, $codeBranch)
    {
        if(!empty($nit) && is_numeric($nit)
            && !empty($codeBranch) && is_string($codeBranch)) {
            $criteria = new CDbCriteria;
            $criteria->addCondition('cef_nit =' . $nit, 'and');
            $criteria->addCondition('cef_codigoSucursalEnv =' . $codeBranch,
                'and');
            $result = self::model()->find($criteria);
            if($result) {
                return $result;
            } else {
                $class = new stdClass();
                $class->cef_codigoSucursalFact = $codeBranch;
                $class->cef_codigoSucursalEnv = $codeBranch;
                return $class;
            }
        }
        return false;
    }

}
