<?php

/**
 * This is the model class for table "b2b_client".
 *
 * The followings are the available columns in table 'b2b_client':
 * @property integer $cln_id
 * @property string $cln_nit
 * @property string $cln_name
 * @property string $cln_codeBranch
 * @property string $cln_nameBranch
 * @property integer $cln_usr_user_ID
 *
 * The followings are the available model relations:
 * @property B2bUser $clnUsrUser
 */
class Client extends CActiveRecord
{
    
    public $radioButton;
    /**
     * @return string the associated database table name
     */
    public function tableName()
    {
        return 'b2b_client';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules()
    {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('cln_nit, cln_name, cln_codeBranch, cln_nameBranch, cln_usr_user_ID', 'required'),
            array('cln_usr_user_ID', 'numerical', 'integerOnly' => true),
            array('cln_nit', 'length', 'max' => 45),
            array('cln_name, cln_codeBranch', 'length', 'max' => 150),
            array('cln_nameBranch', 'length', 'max' => 250),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('radioButton, cln_id, cln_nit, cln_name, cln_codeBranch, cln_nameBranch, cln_usr_user_ID', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations()
    {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'clnUsrUser' => array(self::BELONGS_TO, 'B2bUser', 'cln_usr_user_ID'),
            'budget' => array(self::HAS_MANY, 'Budget', 'id_cln_id'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels()
    {
        return array(
            'cln_id' => 'Cln',
            'cln_nit' => 'Nit',
            'cln_name' => 'Empresa',
            'cln_codeBranch' => 'Codigo sucursal',
            'cln_nameBranch' => 'Sucursal',
            'cln_usr_user_ID' => 'Usuario',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search()
    {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('cln_id', $this->cln_id);
        $criteria->compare('cln_nit', $this->cln_nit, true);
        $criteria->compare('cln_name', $this->cln_name, true);
        $criteria->compare('cln_codeBranch', $this->cln_codeBranch, true);
        $criteria->compare('cln_nameBranch', $this->cln_nameBranch, true);
        $criteria->compare('cln_usr_user_ID', $this->cln_usr_user_ID);

        return new CActiveDataProvider($this,
            array(
            'criteria' => $criteria,
        ));
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function filterClient($idUser)
    {
        // @todo Please modify the following code to remove attributes that should not be searched.                
        $criteria = new CDbCriteria;

        $criteria->compare('cln_id', $this->cln_id);
        $criteria->compare('cln_nit', $this->cln_nit, true);
        $criteria->compare('cln_name', $this->cln_name, true);
        $criteria->compare('cln_codeBranch', $this->cln_codeBranch, true);
        $criteria->compare('cln_nameBranch', $this->cln_nameBranch, true);
        $criteria->compare('cln_usr_user_ID', $idUser);
        
        $criteria->order = 'cln_nameBranch ASC';

        return new CActiveDataProvider($this,
            array(
            'criteria' => $criteria,
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return Client the static model class
     */
    public static function model($className = __CLASS__)
    {
        return parent::model($className);
    }
   

    /**
     * Metodo para obtener el listado de los clientes asociados 
     * al usuario
     * 
     * @param int $idUser Identificador del usuario
     * @return array
     * @author    Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2013 INGENEO S.A.S.
     * @license   http://www.opensource.org/licenses/bsd-license.php  BSD License
     * @version   Release: $Id$
     * @link      http://www.ingeneo.com.co
     */
    public function getListClientSave($idUser)
    {
        $listClient = array();
        if(!empty($idUser) && is_numeric($idUser)) {
            $criteria = new CDbCriteria;

            $criteria->compare('cln_id', $this->cln_id);
            $criteria->compare('cln_nit', $this->cln_nit, true);
            $criteria->compare('cln_name', $this->cln_name, true);
            $criteria->compare('cln_codeBranch', $this->cln_codeBranch, true);
            $criteria->compare('cln_nameBranch', $this->cln_nameBranch, true);
            $criteria->compare('cln_usr_user_ID', $idUser);

            $listClient = CHtml::listData($this->findAll($criteria), 'cln_nit',
                    'cln_name');
        }
        return $listClient;
    }
    
    public function getListClientUpdateBudget($idUser)
    {
        $listClient = array();
        if(!empty($idUser) && is_numeric($idUser)) {
            $criteria = new CDbCriteria;

            $criteria->compare('cln_id', $this->cln_id);
            $criteria->compare('cln_nit', $this->cln_nit, true);
            $criteria->compare('cln_name', $this->cln_name, true);
            $criteria->compare('cln_codeBranch', $this->cln_codeBranch, true);
            $criteria->compare('cln_nameBranch', $this->cln_nameBranch, true);
            $criteria->compare('cln_usr_user_ID', $idUser);

            $listClient = CHtml::listData($this->findAll($criteria), 'cln_id',
                    'cln_name');
            $listBranch = CHtml::listData($this->findAll($criteria), 'cln_id',
                    'cln_nameBranch');
        }
        return array($listClient,$listBranch);
    }
    
    public function getListClientSaveBudget($idUser)
    {
        $listClient = array();
        if(!empty($idUser) && is_numeric($idUser)) {
            $criteria = new CDbCriteria;

            $criteria->compare('cln_id', $this->cln_id);
            $criteria->compare('cln_nit', $this->cln_nit, true);
            $criteria->compare('cln_name', $this->cln_name, true);
            $criteria->compare('cln_codeBranch', $this->cln_codeBranch, true);
            $criteria->compare('cln_nameBranch', $this->cln_nameBranch, true);
            $criteria->compare('cln_usr_user_ID', $idUser);
            $criteria->addCondition('cln_id not in (select id_cln_id from b2b_budget)');

            $listClient = CHtml::listData($this->findAll($criteria), 'cln_nit',
                    'cln_name');
        }
        return $listClient;
    }
    
    public function getListBranchBudget($nit)
    {
        $listBranch = array();
        if(!empty($nit) && is_numeric($nit)) {
            $criteria = new CDbCriteria;            
            $criteria->compare('cln_nit', $nit, true);            
            $criteria->compare('cln_usr_user_ID', User::getId());
            $criteria->addCondition('cln_id not in (select id_cln_id from b2b_budget)');

            $listBranch = CHtml::listData($this->findAll($criteria),
                    'cln_id', 'cln_nameBranch');
        }
        return $listBranch;
    }
    
    public function getListBranchBudgetSearch($nit)
    {
        $listBranch = array();
        if(!empty($nit) && is_numeric($nit)) {
            $criteria = new CDbCriteria;            
            $criteria->compare('cln_nit', $nit, true);            
            $criteria->compare('cln_usr_user_ID', User::getId());            

            $listBranch = CHtml::listData($this->findAll($criteria),
                    'cln_id', 'cln_nameBranch');
        }
        return $listBranch;
    }

    /**
     * Metodo para obtener el listado de las sucursales
     * 
     * @param int $nit NIT del cliente
     * 
     * @return array
     * @author    Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2013 INGENEO S.A.S.
     * @license   http://www.opensource.org/licenses/bsd-license.php  BSD License
     * @version   Release: $Id$
     * @link      http://www.ingeneo.com.co
     * 
     */
    public function getListBranch($nit)
    {
        $listBranch = array();
        if(!empty($nit) && is_numeric($nit)) {
            $criteria = new CDbCriteria;            
            $criteria->compare('cln_nit', $nit, true);            
            $criteria->compare('cln_usr_user_ID', User::getId());

            $listBranch = CHtml::listData($this->findAll($criteria),
                    'cln_codeBranch', 'cln_nameBranch');
        }
        return $listBranch;
    }

    /**
     * Metodo para obtener el nombre del cliente
     * 
     * @param int $nit Nit del cliente
     * 
     * @return string
     * @author    Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2013 INGENEO S.A.S.
     * @license   http://www.opensource.org/licenses/bsd-license.php  BSD License
     * @version   SVN: $Id$
     * @link      http://www.ingeneo.com.co
     */
    public function getNameClient($nit)
    {
        $nameClient = '';
        if(!empty($nit) && is_numeric($nit)) {
            $criteria = new CDbCriteria;

            $criteria->compare('cln_id', $this->cln_id);
            $criteria->compare('cln_nit', $nit, true);
            $criteria->compare('cln_name', $this->cln_name, true);
            $criteria->compare('cln_codeBranch', $this->cln_codeBranch, true);
            $criteria->compare('cln_nameBranch', $this->cln_nameBranch, true);
            $criteria->compare('cln_usr_user_ID', User::getId());

            $result = $this->find($criteria);
            $nameClient = (isset($result->cln_name)) ? $result->cln_name : '';
        }
        return $nameClient;
    }

    /**
     * Metodo para obtener el nombre de la sucursal
     * 
     * @param int $nit        Nit de la empresa
	 * @param int $codeBranch Codigo de la sucursal
     * 
     * @return string
     * @author    Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2013 INGENEO S.A.S.
     * @license   http://www.opensource.org/licenses/bsd-license.php  BSD License
     * @version   SVN: $Id$
     * @link      http://www.ingeneo.com.co
     */
    public function getNameBranch($nit, $codeBranch)
    {
        $nameBranch = '';
        if(!empty($nit) && is_numeric($nit) 
		&& !empty($codeBranch) && is_numeric($codeBranch)) {
            $criteria = new CDbCriteria;

            $criteria->compare('cln_id', $this->cln_id);
            $criteria->compare('cln_nit', $nit, true);
            $criteria->compare('cln_name', $this->cln_name, true);
            $criteria->compare('cln_codeBranch', $codeBranch, true);
            $criteria->compare('cln_nameBranch', $this->cln_nameBranch, true);
            //$criteria->compare('cln_usr_user_ID', User::getId());

            $result = $this->find($criteria);
            $nameBranch = (isset($result->cln_nameBranch)) ? $result->cln_nameBranch : '';
        }
        return $nameBranch;
    }
    
    public function getBudgetClient($nit, $codeBranch){
        $data = array();
        if(!empty($nit) && is_numeric($nit) 
		&& !empty($codeBranch) && is_numeric($codeBranch)) {
            $criteria = new CDbCriteria;    
            //$criteria->select = 'c.bud_block as presupuesto';
            $criteria->compare('cln_nit', $nit, true);
            $criteria->compare('cln_codeBranch', $codeBranch, true);
            $criteria->join = 'LEFT JOIN b2b_budget c on c.id_cln_id = t.cln_id';
            $criteria->addCondition('t.cln_usr_user_ID = ' . User::getId() . '');
            $result = $this->find($criteria);
            if(isset($result->budget) && count($result->budget)>0){
                $budget = $result->budget[0];                
                $data = array(
                    'presupuesto'=>$budget->bud_budget,
                    'bloqueo'=>$budget->bud_block
                );
            }                        
        }
        return $data;
    }

}
