<?php

/**
 * This is the model class for table "b2b_motivos".
 *
 * The followings are the available columns in table 'b2b_motivos':
 * @property integer $mot_id
 * @property integer $mot_nit
 * @property string $mot_nombreCliente
 * @property string $mot_codigoSucursal
 * @property string $mot_nombreSucursal
 * @property string $mot_codigoMotivo
 * @property string $mot_nombreMotivo
 */
class Motivos extends CActiveRecord
{
    
    const CODE_DEFAULT = '1';
    
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'b2b_motivos';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('mot_nit, mot_codigoSucursal, mot_codigoMotivo', 'required'),
			array('mot_nit', 'numerical', 'integerOnly'=>true),
			array('mot_nombreCliente', 'length', 'max'=>150),
			array('mot_codigoSucursal, mot_codigoMotivo', 'length', 'max'=>45),
			array('mot_nombreSucursal, mot_nombreMotivo', 'length', 'max'=>250),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('mot_id, mot_nit, mot_nombreCliente, mot_codigoSucursal, mot_nombreSucursal, mot_codigoMotivo, mot_nombreMotivo', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'mot_id' => 'Mot',
			'mot_nit' => 'Nit del cliente',
			'mot_nombreCliente' => 'Nombre del cliente',
			'mot_codigoSucursal' => 'Codigo de la sucursal',
			'mot_nombreSucursal' => 'Nombre de la sucursal',
			'mot_codigoMotivo' => 'codigo del motivo',
			'mot_nombreMotivo' => 'nombre del motivo',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('mot_id',$this->mot_id);
		$criteria->compare('mot_nit',$this->mot_nit);
		$criteria->compare('mot_nombreCliente',$this->mot_nombreCliente,true);
		$criteria->compare('mot_codigoSucursal',$this->mot_codigoSucursal,true);
		$criteria->compare('mot_nombreSucursal',$this->mot_nombreSucursal,true);
		$criteria->compare('mot_codigoMotivo',$this->mot_codigoMotivo,true);
		$criteria->compare('mot_nombreMotivo',$this->mot_nombreMotivo,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Motivos the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
    
    /**
     * Metodo para obtener el motivo
     * 
     * @param int    $nit        Nit del cliente
     * @param string $codeBranch Codigo de la sucursal
     * 
     * @return boolean
     * @author Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2013 INGENEO S.A.S.
     * @license http://www.opensource.org/licenses/bsd-license.php  BSD License
     * @version Release: $Id$
     */
    public static function getMotivo($nit, $codeBranch){
        if(!empty($nit) && is_numeric($nit) 
            && !empty($codeBranch) && is_string($codeBranch)){
            $criteria=new CDbCriteria;
            $criteria->addCondition('mot_nit =' . $nit,'and');
            $criteria->addCondition('mot_codigoSucursal =' . $codeBranch,'and');
            $result = self::model()->find($criteria);
            if($result){
                return $result->mot_codigoMotivo;
            }else{
                return self::CODE_DEFAULT;
            }
        }
        return false;
    }
    
}
