<?php

/**
 * This is the model class for table "b2b_order".
 *
 * The followings are the available columns in table 'b2b_order':
 * @property integer $ord_id
 * @property string $ord_nit
 * @property string $ord_codeBranch
 * @property string $ord_description
 * @property integer $ord_number
 * @property string $ord_status
 * @property string $ord_date
 * @property integer $ord_objOrder
 * @property string $ord_income_type
 * @property integer $ord_total_net
 * @property integer $ord_total_discount
 * @property integer $ord_total_iva
 * @property integer $ord_total
 * @property string $ord_user
 * @property string $ord_user_allow
 *
 * The followings are the available model relations:
 * @property B2bOrderProduct[] $b2bOrderProducts
 */
class Order extends CActiveRecord
{

    const STATUS_PENDING = 'pendiente';
    const STATUS_ALLOW = 'autorizado';
    const STATUS_PARCIAL = 'parcial';
    const STATUS_DELETE = 'borrado';
    const ORDER_NEW = 'nuevo';
    const TYPE_INCOME_EXCEL = 'excel';
    const TYPE_INCOME_FILE = 'archivo';
    const TYPE_INCOME_MULTI_BRANCH = 'multibranch';
    const TYPE_INCOME_CATALOG = 'catalogo';
    const TYPE_INCOME_FORM = 'referencia';
    const RADIO_REMISION = 'RV';
    const COD_FACTURACION = '1';
    const COD_REMISION = '2';

    public $ord_nameBranch;
    public $ord_nameClient;
    public $file;
    public $filterDesc;
    public $filterRef;
    public $checkRemision;
    public $sendMail;
    public $quantity;
    
    public $start_date;
    public $end_date;

    /**
     * @return string the associated database table name
     */
    public function tableName()
    {
        return 'b2b_order';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules()
    {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('ord_objOrder, ord_date', 'required', 'on' => 'createOrder'),
//            array('ord_nit, ord_codeBranch, ord_status, ord_date, 
//                ord_income_type, ord_user',
//                'required'),
            array('ord_date', 'compare', 'compareValue' => date('Y-m-d'), 'operator' => '>'),
            array('ord_total_net, ord_total_discount, ord_total_iva, ord_total',
                'numerical', 'integerOnly' => true),
            array('ord_nit', 'length', 'max' => 45),
            array('ord_number', 'length', 'max' => 15),
            array('ord_codeBranch, ord_user, ord_user_allow', 'length', 'max' => 250),
            array('ord_description', 'length', 'max' => 55),
            array('ord_status', 'length', 'max' => 15),
            array('ord_income_type', 'length', 'max' => 15),
            array('ord_objOrder', 'required', 'message' => 'Seleccione el objeto del pedido (Facturación o Remisión)'),
//            array('remision','radioValidate','ord_objOrder','rem'),
//            array('factura','radioValidate','ord_objOrder','fact'),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('ord_id, ord_nit, ord_codeBranch, ord_number, ord_description, ord_status, ord_date, ord_income_type, ord_total_net, ord_total_discount, ord_total_iva, ord_total, ord_user, ord_user_allow',
                'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations()
    {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'b2bOrderProducts' => array(self::HAS_MANY, 'OrderProduct', 'orp_ord_id'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels()
    {
        return array(
            'ord_id' => 'No. Transferencia',
            'ord_nit' => 'Nit',
            'ord_nameClient' => 'Cliente',
            'ord_codeBranch' => 'Codigo sucursal',
            'ord_description' => 'Descripción',
            'ord_number' => 'Numero de la orden',
            'ord_status' => 'Estado',
            'ord_date' => 'Fecha entrega',
            'ord_income_type' => 'Tipo de ingreso',
            'ord_total_net' => 'Total neto',
            'ord_total_discount' => 'Total con descuento',
            'ord_total_iva' => 'Total iva',
            'ord_total' => 'Total',
            'ord_user' => 'Usuario',
            'ord_user_allow' => 'Usuario',
            'ord_objOrder' => 'Objeto del pedido',
            'ord_nameBranch' => 'Sede',
            'quantity' => 'Cantidad',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search()
    {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('ord_id', $this->ord_id);
        $criteria->compare('ord_nit', $this->ord_nit, true);
        $criteria->compare('ord_codeBranch', $this->ord_codeBranch, true);
        $criteria->compare('ord_number', $this->ord_number);
        $criteria->compare('ord_description', $this->ord_description, true);
        $criteria->compare('ord_status', $this->ord_status, true);
        $criteria->compare('ord_date', $this->ord_date, true);
        $criteria->compare('ord_income_type', $this->ord_income_type, true);
        $criteria->compare('ord_total_net', $this->ord_total_net);
        $criteria->compare('ord_total_discount', $this->ord_total_discount);
        $criteria->compare('ord_total_iva', $this->ord_total_iva);
        $criteria->compare('ord_total', $this->ord_total);
        $criteria->compare('ord_user_allow', $this->ord_user_allow);
        
        
        if(isset($this->start_date) && !empty($this->start_date)
            && isset($this->end_date) && !empty($this->end_date)){
            $criteria->addBetweenCondition('ord_date', "".$this->start_date."", "".$this->end_date."");
        }

        $criteria = $this->_conditions($criteria);

        return new CActiveDataProvider($this,
            array(
            'criteria' => $criteria,
                'sort' => false,
                'pagination' => false,
                
        ));
    }

    /**
     * Funcion para las condiciones del criteria
     * 
     * @param object $criteria Criteria
     * 
     * @return    object
     * @author    Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2014 INGENEO S.A.S.
     * @license   http://www.opensource.org/licenses/bsd-license.php  BSD License
     * @version   SVN: $Id$
     * @link      http://www.ingeneo.com.co
     */
    private function _conditions($criteria)
    {
        $idUser = User::getId();
        $client = new Client;
        $listClient = $client->getListClientSave($idUser);
        $arrayNit = array_keys($listClient);
        
        if(empty($this->ord_user_allow)){
        $criteria->addCondition('ord_status != "' . Order::STATUS_ALLOW . '"',
            'and');
        }

        if(!empty($this->ord_date)) {
            $criteria->addCondition('ord_date like "%' . $this->ord_date . '%"',
                'or');
        }

        if(count($arrayNit) > 0) {
            $model = Client::model()->findAll(
                'cln_usr_user_ID = ' . User::getId()
                . ' AND cln_nit IN (' . implode(',', $arrayNit) . ')'
            );
            $listBranch = CHtml::listData($model, 'cln_codeBranch',
                    'cln_codeBranch');               
            if(count($listBranch) > 0) {
                $criteria->addCondition('(ord_nit in(' . implode(',', $arrayNit)
                    . ') AND ord_codeBranch in(' . implode(',',
                        $listBranch) . '))', 'and');
            } else {
                $criteria->addCondition('ord_nit in(' . implode(',', $arrayNit)
                    . ')', 'and');
            }
        }

        if(Yii::app()->user->checkAccess(Rol::ROL_SHOP)) {
            $criteria->addCondition('(ord_status != "' . Order::STATUS_PENDING
                . '" )', 'and');
            $criteria->addCondition('ord_user = "' . Yii::app()->user->name
                . '"', 'and');
        } elseif(Yii::app()->user->checkAccess(Rol::ROL_SALES)) {
            $criteria->addCondition('ord_user = "' . Yii::app()->user->name
                . '"', 'and');
        }
		/*else {
            $criteria->addCondition('ord_user = "' . Yii::app()->user->name
                . '"', 'OR');
        }*/
        return $criteria;
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return Order the static model class
     */
    public static function model($className = __CLASS__)
    {
        return parent::model($className);
    }

    /**
     * Metodo para obtener el nombre del cliente
     * 
     * @param int $nit Nit del cliente
     * 
     * @return string
     * @author    Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2013 INGENEO S.A.S.
     * @license   http://www.opensource.org/licenses/bsd-license.php  BSD License
     * @version   SVN: $Id$
     * @link      http://www.ingeneo.com.co
     */
    public static function getNameClient($nit)
    {
        $client = new Client;
        return $client->getNameClient($nit);
    }

    /**
     * Metodo para obtener el nombre de la sucursal
     * 
     * @param int $nit        Nit de la empresa
     * @param int $codeBranch Codigo de la sucursal
     * 
     * @return string
     * @author    Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2013 INGENEO S.A.S.
     * @license   http://www.opensource.org/licenses/bsd-license.php  BSD License
     * @version   SVN: $Id$
     * @link      http://www.ingeneo.com.co
     */
    public static function getNameBranch($nit, $codeBranch)
    {
        $client = new Client;
        return $client->getNameBranch($nit, $codeBranch);
    }

    /**
     * Metodo para obtener el listado de los estados
     * 
     * @return array
     * @author    Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2013 INGENEO S.A.S.
     * @license   http://www.opensource.org/licenses/bsd-license.php  BSD License
     * @version   SVN: $Id$
     * @link      http://www.ingeneo.com.co
     */
    public function listStatus()
    {                
        return array(
            //self::STATUS_ALLOW => self::STATUS_ALLOW,
            ''=>'Todos',
            self::STATUS_PARCIAL => self::STATUS_PARCIAL,
            self::STATUS_PENDING => self::STATUS_PENDING
        );
    }

    /**
     * Metodo para obtener el icono segun el estado
     * 
     * @param string $status estado del pedido
     * 
     * @return string
     * @author    Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2013 INGENEO S.A.S.
     * @license   http://www.opensource.org/licenses/bsd-license.php  BSD License
     * @version   SVN: $Id$
     * @link      http://www.ingeneo.com.co
     */
    public function getIconStatus($status)
    {
        $html = '';
        if(!empty($status)) {
            switch($status) {
                case (self::STATUS_ALLOW):
                    $html = TbHtml::icon(TbHtml::ICON_OK);
                    break;
                case (self::STATUS_PENDING):
                    $html = TbHtml::icon(TbHtml::ICON_WARNING_SIGN);
                    break;
                default:
                    $html = TbHtml::icon(TbHtml::ICON_QUESTION_SIGN);
                    break;
            }
        }
        return $html;
    }

    /**
     * Metodo que permite validar segun el estado si habilita 
     * o no el link para la liquidacion del pedido
     * 
     * @param int    $idOrder Identiicador de la orden
     * @param string $status  Estado de la orden
     * 
     * @return string
     * @author    Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2013 INGENEO S.A.S.
     * @license   http://www.opensource.org/licenses/bsd-license.php  BSD License
     * @version   SVN: $Id$
     * @link      http://www.ingeneo.com.co
     */
    public function validateLinkLiq($idOrder, $status)
    {
        $link = '';
        if(!empty($idOrder) && !empty($status) && is_numeric($idOrder)) {
            if(Yii::app()->user->checkAccess(Rol::ROL_SHOP)
                && $status === self::STATUS_PENDING) {
                $link = $idOrder;
            } elseif($status !== self::STATUS_ALLOW) {
                $link = CHtml::link($idOrder,
                        Yii::app()
                            ->createUrl("order/liquidate",
                                array("id" => $idOrder)));
            } else {
                $link = $idOrder;
            }
        }
        return $link;
    }

    /**
     * Funcion que permite habilitar la eliminacion de pedidos
     * 
     * @param string $status Estado del pedido
     * 
     * @return boolean
     * @author    Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2013 INGENEO S.A.S.
     * @license   http://www.opensource.org/licenses/bsd-license.php  BSD License
     * @version   SVN: $Id$
     * @link      http://www.ingeneo.com.co
     */
    public function validateDelete($status)
    {
        if(!empty($status)) {
            if(Yii::app()->user->checkAccess(Rol::ROL_SHOP)
                && $status === self::STATUS_PENDING) {
                return false;
            }
        }
        return true;
    }

    /**
     * Metodo para obtener el objeto del pedido
     * 
     * @param int $code codigo valoe ente (1,2)
     * 
     * @return string
     * @author    Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2013 INGENEO S.A.S.
     * @license   http://www.opensource.org/licenses/bsd-license.php  BSD License
     * @version   SVN: $Id$
     * @link      http://www.ingeneo.com.co
     */
    public function getObjOrder($code)
    {
        $arrayObjectOrder = array(
            self::COD_FACTURACION => 'F:',
            self::COD_REMISION => 'R:',
        );
        return (isset($arrayObjectOrder[$code])) ? $arrayObjectOrder[$code] : '';
    }

    /**
     * Metodo para calcular el numero de dias 
     * entre la fecha de entrega y la fecha actual del sistema
     * 
     * @param string $fecha Fecha de entrega
     * 
     * @return boolean
     * @author    Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2014 INGENEO S.A.S.
     * @license   http://www.opensource.org/licenses/bsd-license.php  BSD License
     * @version   SVN: $Id$
     * @link      http://www.ingeneo.com.co
     */
    public function getNumDiasEntrega($fecha)
    {
        if(!empty($fecha) && is_string($fecha)) {
            $segundos = strtotime($fecha) - strtotime(date('Y-m-d'));
            return intval($segundos / 60 / 60 / 24);
        }
        return false;
    }

    /**
     * Metodo para validar el acceso de ordenes al modulo de liquidacion 
     * 
     * @param int $idOrder id de la orden
     * 
     * @return boolean
     * @author    Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2014 INGENEO S.A.S.
     * @license   http://www.opensource.org/licenses/bsd-license.php  BSD License
     * @version   SVN: $Id$
     * @link      http://www.ingeneo.com.co
     */
    public function validateLiquidateOrder($idOrder)
    {
        if(!empty($idOrder) && is_numeric($idOrder)) {

            $criteria = new CDbCriteria;
            $criteriaCondition = $this->_conditions($criteria);
            $result = self::model()->findAll($criteriaCondition);
            $data = CHtml::listData($result, 'ord_id', 'ord_id');
            if(is_array($data) && count($data) > 0 && in_array($idOrder, $data)) {
                return true;
            }
        }
        return false;
    }
    
    /**
     * Metodo para enviar el correo con la informacion 
     * del pedido
     * 
     * @param Order $model
     * 
     * @author Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2017 INGENEO S.A.S.
     * @license http://www.opensource.org/licenses/bsd-license.php  BSD License
     * @version SVN: $Id$
     */
    public static function sendMailVendedor($model) {
        $client = new Client;
        $arrayEmail = [];
        // Informacion del cliente y la sucursal -------------------------------
        $nameClient = $client->getNameClient($model->ord_nit);
        $nameBranch = $client->getNameBranch($model->ord_nit, $model->ord_codeBranch);
        //Listado de productos -------------------------------------------------
        $orderProduct = new OrderProduct;
        $listProduct = $orderProduct->getProducts($model->ord_id);        
        //Verificamos si hay inventario en 0 -----------------------------------
        $notifVendedor = false;
        foreach ($listProduct as $product) {
            //si la cantidad es mayor al inventario notificamos al venedor                            
            if($product['orp_und_exist'] != '' && is_numeric($product['orp_und_exist'])){                                                            
                if($product['orp_amount'] > $product['orp_und_exist']){                                    
                    $notifVendedor = true;
                }
            }else{
                $notifVendedor = true;
            }
        }  
        if($notifVendedor){
            //Traemos la info del vendedor -----------------------------------------
            $infoVendedor = ClientSiesa::getInfoVendedor($model->ord_nit, $model->ord_codeBranch);
            if(count($infoVendedor)>0){
                $arrayEmail[] = $infoVendedor[0]['email'];                
                $arrayEmail[] = 'soporte@jdh.com.co';
                Yii::log(__FILE__ . ':' . __LINE__ . ':' . __FUNCTION__
                        . ':' . ' {_emails ['
                        . print_r($arrayEmail, true) . ']}', CLogger::LEVEL_ERROR, 'b2b.mail');
            }          

            $subject = 'JDH - B2B - Pedido con Faltantes';
            if (isset(Yii::app()->controller)){
               $message = Yii::app()->controller->renderPartial('templateMailPendient', array(
                    'model' => $model,
                    'nameBranch' => $nameBranch,
                    'nameClient' => $nameClient,
                    'listProduct' => $listProduct,
                        ), true, false); 
            }else{
                $views = Yii::app()->getBasePath().DIRECTORY_SEPARATOR.'views';
                $viewsOrder = $views.DIRECTORY_SEPARATOR.'order'.DIRECTORY_SEPARATOR;
                $view = $viewsOrder.'templateMailPendientConsole.php';
				
                $controller = new OrderController("Order"); 
				$data = array(
                    'model' => $model,
                    'nameBranch' => $nameBranch,
                    'nameClient' => $nameClient,
                    'listProduct' => $listProduct,
                        );
				$message = $controller->renderInternal($view, $data, true);

				/*
                $message = $controller->renderFile($view,array(
						'model' => $model,
						'nameBranch' => $nameBranch,
						'nameClient' => $nameClient,
						'listProduct' => $listProduct,
							),true);*/
					
				}
                                   
            $mail = new Mail();
            try {
                $mail->sendMail($arrayEmail, $message, $subject);
            } catch (Exception $exc) {            
                Yii::log(__FILE__ . ':' . __LINE__ . ':' . __FUNCTION__
                        . ':' . ' {_sendMail ERROR ['
                        . $exc->getMessage() . ']}', CLogger::LEVEL_ERROR, 'b2b.mail');
            }        
        }        
    }
    
    /**
     * Retorna la informacion de la facturacion 
     * 
     * @param int $nit
     * @param int $codeBranch
     * 
     * @return type
     * @author Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2017 INGENEO S.A.S.
     * @license http://www.opensource.org/licenses/bsd-license.php  BSD License
     * @version SVN: $Id$
     */
    public function infoBudget($nit, $codeBranch){
        $presupuesto = 0;
        $bloqueo = 'NO';
        $infoBudget = array(
            'bloqueo_pedidos'=>'NO',
            'presupuesto'=>$presupuesto,
            'bloqueo'=>$bloqueo,
            'acumulado'=>0,
        );        
        if(!empty($nit) && is_numeric($nit) 
		&& !empty($codeBranch) && is_numeric($codeBranch)) {            
            $data = Yii::app()->db->createCommand(
                    "SELECT bud.bud_budget as presupuesto, bud_block as bloqueo 
                    FROM b2b_budget bud 
                    JOIN b2b_client c ON bud.id_cln_id = c.cln_id 
                    WHERE c.cln_nit = '".$nit."' AND c.cln_codeBranch = '"
                    .$codeBranch."' ")->queryRow();
            //AND c.cln_usr_user_ID = '".User::getId()."'
            
            $clientSiesa = new ClientSiesa;                
            $infoBudgetSiesa = $clientSiesa->getAcumuladoPedidos($nit, $codeBranch);  
 
            if(is_array($data) && count($data)>0 && isset($data['presupuesto'])){   
                $presupuesto = $data['presupuesto'];
                $bloqueo = $data['bloqueo'];                                
                if($data['bloqueo'] == Budget::BLOQUEO_SI){                    
                    if(($infoBudgetSiesa >= $data['presupuesto'])){
                        $infoBudget['bloqueo_pedidos'] = 'SI';
                    }                    
                }                
            } 
            $infoBudget['acumulado'] = $infoBudgetSiesa;
            $infoBudget['bloqueo'] = $bloqueo;
            $infoBudget['presupuesto'] = $presupuesto;
        }
        return $infoBudget;
    }
    
    /**
     * Retorna el limite minimo de pedido
     * 
     * @return int
     * @author Alexander Arcila <alexander.arcila@ingeneo.com.co>
     * @copyright 2017 INGENEO S.A.S.
     * @license http://www.opensource.org/licenses/bsd-license.php  BSD License
     * @version SVN: $Id$
     */
    public function getLimitOrder(){
        $result = Parameter::model()->find("clave = 'limit_order'");
        if(!empty($result) && isset($result->valor) && is_numeric($result->valor)){
            return $result->valor;
        }
        return 0;
    }
}
